# -*- coding: utf-8 -*-

"""
AWS Environment and Deployment component.
"""

import typing as T
import sys
import hashlib

from aws_cloudformation import deploy_stack, remove_stack
from aws_cloudformation.stack import Parameter

from .template import Template
from .console import get_s3_console_url
from ..res.cloudformation import Stack

if T.TYPE_CHECKING:
    from boto_session_manager import BotoSesManager

DEFAULT_S3_PREFIX_FOR_TEMPLATE = "cloudformation/template"
DEFAULT_S3_PREFIX_FOR_STACK_POLICY = "cloudformation/policy"

DEFAULT_UPDATE_DELAYS = 5
DEFAULT_UPDATE_TIMEOUT = 60
DEFAULT_CHANGE_SET_DELAYS = 5
DEFAULT_CHANGE_SET_TIMEOUT = 60


def md5_of_text(text: str) -> str:
    """
    Return md5 of text.
    """
    md5 = hashlib.md5()
    md5.update(text.encode("utf-8"))
    return md5.hexdigest()


def detect_template_type(template: str) -> str:
    """
    Detect whether CloudFormation template is JSON or YAML.

    :return: "json" or "yaml"
    """
    if template.strip().startswith("{"):
        return "json"
    else:  # pragma: no cover
        return "yaml"


class Env:
    """
    Environment is simply an abstraction layer with a boto3 session object
    connected to AWS, allowing you to perform AWS API call.

    You are responsible to create you own boto session manager object.
    You can find more information about ``BotoSesManager`` at
    https://github.com/MacHu-GWU/boto_session_manager-project

    1. Local laptop environment, using default AWS credential based on the
        environment variable https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-envvars.html,
        or based on the default profile in ``~/.aws/credentials``:

    .. code-block:: python

        import boto3

        bsm = BotoSesManager()

    2. Local laptop environment, using named profile. You have to configure the
        ``~/.aws/credentials`` and ``~/.aws/config`` file. Here's how
        https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-profiles.html:

    .. code-block:: python

        bsm = BotoSesManager(profile_name="your_aws_profile")

    3. EC2 or AWS Lambda environment, using IAM role. It is exactly same to #1

    4. Load credential in a secure way, manually pass in credential to the session:

    .. code-block:: python

        bsm = BotoSesManager(
            aws_access_key_id="your_access_key",
            aws_secret_access_key="your_secret_access_key",
            region_name="us-east-1",
        )

    .. versionadded:: 1.0.1
    """

    def __init__(
        self,
        bsm: "BotoSesManager" = None,
        is_us_gov_cloud: bool = False,
    ):
        if bsm is None:
            self.bsm = BotoSesManager()
        else:
            self.bsm = bsm
        self.is_us_gov_cloud = is_us_gov_cloud

    @property
    def s3_client(self):
        return self.bsm.get_client("s3")

    @property
    def cf_client(self):
        return self.bsm.get_client("cloudformation")

    def upload_template(
        self,
        template: Template,
        bucket: str,
        prefix: str = DEFAULT_S3_PREFIX_FOR_TEMPLATE,
    ) -> T.Tuple[str, str]:
        """
        Upload cloudformation template to s3 bucket and returns template url.
        It is a format like this https://s3.amazonaws.com/<s3-bucket-name>/<s3-key>

        :return: s3 url of the template file

        .. versionadded:: 1.0.1
        """
        template_body = template.to_json()
        filename = md5_of_text(template_body)
        template_type = detect_template_type(template_body)
        if prefix.endswith("/"):
            prefix = prefix[:-1]
        key = f"{prefix}/{filename}.{template_type}"
        self.s3_client.put_object(
            Bucket=bucket,
            Key=key,
            Body=template_body,
        )
        template_url = "https://s3.amazonaws.com/{}/{}".format(bucket, key)
        s3_console_url = get_s3_console_url(
            bucket=bucket,
            prefix=key,
            is_us_gov_cloud=self.is_us_gov_cloud,
        )
        return template_url, s3_console_url

    def package(
        self,
        template: Template,
        bucket: str,
        prefix: str = DEFAULT_S3_PREFIX_FOR_TEMPLATE,
        verbose: bool = True,
        _is_master: bool = True,
    ):
        """
        Automatically upload nested stack template and update template url
        in your CloudFormation code.

        It's a depth-first-search.
        """
        stack_resource: Stack
        for stack_resource in template.Resources.values():
            if stack_resource.AWS_OBJECT_TYPE != Stack.AWS_OBJECT_TYPE:
                continue

            nested_template = template.NestedStack[stack_resource.id]
            self.package(
                template=nested_template,
                bucket=bucket,
                prefix=prefix,
                verbose=verbose,
                _is_master=False,
            )

            if bucket is None:
                raise ValueError(
                    "Because you have a nested template, "
                    "you have to upload template to S3 bucket! "
                    "However ``bucket_name`` is None"
                )
            nested_template_url, nested_template_s3_console_url = self.upload_template(
                template=nested_template,
                bucket=bucket,
                prefix=prefix,
            )
            stack_resource.rp_TemplateURL = nested_template_url

            if verbose:
                msg = (
                    "upload the Template('{}') for nested Template('{}').Stack('{}') "
                    "to s3: {}. view it in aws console: {}"
                ).format(
                    nested_template.Description,
                    template.Description,
                    stack_resource.id,
                    nested_template_url,
                    nested_template_s3_console_url,
                )
                print(msg)

    def deploy(
        self,
        stack_name: str,
        template: Template,
        use_previous_template: T.Optional[bool] = None,
        bucket: T.Optional[str] = None,
        prefix: T.Optional[str] = DEFAULT_S3_PREFIX_FOR_TEMPLATE,
        parameters: T.List[Parameter] = None,
        tags: dict = None,
        execution_role_arn: T.Optional[str] = None,
        include_iam: bool = False,
        include_named_iam: bool = False,
        include_macro: bool = False,
        stack_policy: T.Optional[str] = None,
        prefix_stack_policy: T.Optional[str] = DEFAULT_S3_PREFIX_FOR_STACK_POLICY,
        resource_types: T.Optional[T.List[str]] = None,
        client_request_token: T.Optional[str] = None,
        enable_termination_protection: T.Optional[bool] = None,
        disable_rollback: T.Optional[bool] = None,
        wait: bool = True,
        delays: T.Union[int, float] = DEFAULT_UPDATE_DELAYS,
        timeout: T.Union[int, float] = DEFAULT_UPDATE_TIMEOUT,
        plan_nested_stack: bool = True,
        skip_plan: bool = False,
        skip_prompt: bool = False,
        change_set_delays: T.Union[int, float] = DEFAULT_CHANGE_SET_DELAYS,
        change_set_timeout: T.Union[int, float] = DEFAULT_CHANGE_SET_TIMEOUT,
        verbose: bool = True,
    ):
        """
        Deploy (create or update) an AWS CloudFormation stack. But way more powerful
        than the original boto3 API.

        Reference:

        - Create Stack Boto3 API: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.create_stack
        - Update Stack Boto3 API: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.update_stack

        :param stack_name: the stack name or unique stack id
        :param template: :class:`~cottonformation.core.template.Template` object
        :param use_previous_template: see "Update Stack Boto3 API" link
        :param bucket: default None; if given, automatically upload template to S3
            before deployment. see :func:`~aws_cloudformation.better_boto.upload_template_to_s3`
            for more details.
        :param prefix: the s3 prefix where you want to upload the template to
        :param parameters: see "Update Stack Boto3 API" link
        :param tags: see "Update Stack Boto3 API" link
        :param execution_role_arn: see "Update Stack Boto3 API" link
        :param include_iam: see "Capacities" part in "Update Stack Boto3 API" link
        :param include_named_iam: see "Capacities" part in "Update Stack Boto3 API" link
        :param include_macro: see "Capacities" part in "Update Stack Boto3 API" link
        :param stack_policy: Stack Policy JSON or Yaml body in text, or the
            s3 uri pointing to a Stack Policy JSON template file.
        :param prefix_stack_policy: see "Update Stack Boto3 API" link
        :param resource_types: see "Update Stack Boto3 API" link
        :param client_request_token: see "Update Stack Boto3 API" link
        :param enable_termination_protection: see "Create Stack Boto3 API" link
        :param disable_rollback: see "Update Stack Boto3 API" link
        :param wait: default True; if True, then wait the create / update action
            to success or fail; if False, then it is an async call and return immediately;
            note that if you have skip_plan is False (using change set), you always
            have to wait the change set creation to finish.
        :param delays: how long it waits (in seconds) between two
            "describe_stacks" api call to get the stack status
        :param timeout: how long it will raise timeout error
        :param skip_plan: default False; if False, force to use change set to
            create / update; if True, then do create / update without change set.
        :param skip_prompt: default False; if False, you have to enter "Yes"
            in prompt to do deployment; if True, then execute the deployment directly.
        :param change_set_delays: how long it waits (in seconds) between two
            "describe_change_set" api call to get the change set status
        :param change_set_timeout: how long it will raise timeout error
        :param verbose: whether you want to log information to console

        :return: Nothing

        .. versionadded:: 1.0.1
        """
        stack_console_url = "https://console.aws.amazon.com/cloudformation/home?region={aws_region}#/stacks?filteringStatus=active&filteringText={stack_name}&viewNested=true&hideStacks=false&stackId=".format(
            aws_region=self.bsm.aws_region,
            stack_name=stack_name,
        )
        if verbose:
            print(f"open cloudformation console for status: {stack_console_url}")

        self.package(
            template=template,
            bucket=bucket,
            prefix=prefix,
            verbose=verbose,
        )

        deploy_stack(
            bsm=self.bsm,
            stack_name=stack_name,
            template=template.to_json(),
            use_previous_template=use_previous_template,
            bucket=bucket,
            prefix=prefix,
            parameters=parameters,
            tags=tags,
            execution_role_arn=execution_role_arn,
            include_iam=include_iam,
            include_named_iam=include_named_iam,
            include_macro=include_macro,
            stack_policy=stack_policy,
            prefix_stack_policy=prefix_stack_policy,
            resource_types=resource_types,
            client_request_token=client_request_token,
            enable_termination_protection=enable_termination_protection,
            disable_rollback=disable_rollback,
            wait=wait,
            delays=delays,
            timeout=timeout,
            plan_nested_stack=plan_nested_stack,
            skip_plan=skip_plan,
            skip_prompt=skip_prompt,
            change_set_delays=change_set_delays,
            change_set_timeout=change_set_timeout,
            verbose=verbose,
        )

    def delete(
        self,
        stack_name: str = None,
        retain_resources: T.Optional[T.List[str]] = None,
        role_arn: T.Optional[bool] = None,
        client_request_token: T.Optional[str] = None,
        wait: bool = True,
        delays: T.Union[int, float] = DEFAULT_UPDATE_DELAYS,
        timeout: T.Union[int, float] = DEFAULT_UPDATE_TIMEOUT,
        skip_prompt: bool = False,
        verbose: bool = True,
    ):
        """
        Delete an AWS CloudFormation Stack.

        Reference:

        - Delete Stack Boto3 API: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.delete_stack

        :param stack_name: the stack name or unique stack id
        :param retain_resources: see "Delete Stack Boto3 API" link
        :param role_arn: see "Delete Stack Boto3 API" link
        :param client_request_token: see "Delete Stack Boto3 API" link
        :param wait: default True; if True, then wait the delete action
            to success or fail; if False, then it is an async call and return immediately.
        :param delays: how long it waits (in seconds) between two
            "describe_stacks" api call to get the stack status
        :param timeout: how long it will raise timeout error
        :param skip_prompt: default False; if False, you have to enter "Yes"
            in prompt to do deletion; if True, then execute the deletion directly.
        :param verbose: whether you want to log information to console

        .. versionadded:: 1.0.1
        """
        remove_stack(
            bsm=self.bsm,
            stack_name=stack_name,
            retain_resources=retain_resources,
            role_arn=role_arn,
            client_request_token=client_request_token,
            wait=wait,
            delays=delays,
            timeout=timeout,
            skip_prompt=skip_prompt,
            verbose=verbose,
        )

    def validate(
        self,
        template: Template,
        bucket: str = None,
        prefix: str = DEFAULT_S3_PREFIX_FOR_TEMPLATE,
    ) -> dict:
        """
        Validate if a :class:`~cottonformation.core.template.Template` object
        is valid.

        TODO: not a stable API

        .. versionadded:: 0.0.8
        """
        template_body = template.to_json(human_readable=False)
        kwargs = dict()
        if sys.getsizeof(template_body) >= 51200:
            if bucket is None:
                raise ValueError(
                    "the body of Template is too large! you have to specify "
                    "``bucket_name`` argument to upload it to S3!"
                )
            template_url, _ = self.upload_template(
                template=template,
                bucket=bucket,
                prefix=prefix,
            )
            kwargs["TemplateURL"] = template_url
        else:
            kwargs["TemplateBody"] = template_body

        return self.cf_client.validate_template(**kwargs)



# -*- coding: utf-8 -*-

class _AwsManagedPolicy:
    AWSDirectConnectReadOnlyAccess = "arn:aws:iam::aws:policy/AWSDirectConnectReadOnlyAccess"
    AmazonGlacierReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonGlacierReadOnlyAccess"
    AWSMarketplaceFullAccess = "arn:aws:iam::aws:policy/AWSMarketplaceFullAccess"
    ClientVPNServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ClientVPNServiceRolePolicy"
    AWSSSODirectoryAdministrator = "arn:aws:iam::aws:policy/AWSSSODirectoryAdministrator"
    AWSIoT1ClickReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIoT1ClickReadOnlyAccess"
    AutoScalingConsoleReadOnlyAccess = "arn:aws:iam::aws:policy/AutoScalingConsoleReadOnlyAccess"
    AmazonDMSRedshiftS3Role = "arn:aws:iam::aws:policy/service-role/AmazonDMSRedshiftS3Role"
    AWSQuickSightListIAM = "arn:aws:iam::aws:policy/service-role/AWSQuickSightListIAM"
    AWSHealthFullAccess = "arn:aws:iam::aws:policy/AWSHealthFullAccess"
    AlexaForBusinessGatewayExecution = "arn:aws:iam::aws:policy/AlexaForBusinessGatewayExecution"
    AmazonElasticTranscoder_ReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonElasticTranscoder_ReadOnlyAccess"
    AmazonRDSFullAccess = "arn:aws:iam::aws:policy/AmazonRDSFullAccess"
    SupportUser = "arn:aws:iam::aws:policy/job-function/SupportUser"
    AmazonEC2FullAccess = "arn:aws:iam::aws:policy/AmazonEC2FullAccess"
    SecretsManagerReadWrite = "arn:aws:iam::aws:policy/SecretsManagerReadWrite"
    AWSIoTThingsRegistration = "arn:aws:iam::aws:policy/service-role/AWSIoTThingsRegistration"
    AmazonDocDBReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonDocDBReadOnlyAccess"
    AmazonMQApiFullAccess = "arn:aws:iam::aws:policy/AmazonMQApiFullAccess"
    AWSElementalMediaStoreReadOnly = "arn:aws:iam::aws:policy/AWSElementalMediaStoreReadOnly"
    AWSCertificateManagerReadOnly = "arn:aws:iam::aws:policy/AWSCertificateManagerReadOnly"
    AWSQuicksightAthenaAccess = "arn:aws:iam::aws:policy/service-role/AWSQuicksightAthenaAccess"
    AWSCloudMapRegisterInstanceAccess = "arn:aws:iam::aws:policy/AWSCloudMapRegisterInstanceAccess"
    AWSMarketplaceImageBuildFullAccess = "arn:aws:iam::aws:policy/AWSMarketplaceImageBuildFullAccess"
    AWSCodeCommitPowerUser = "arn:aws:iam::aws:policy/AWSCodeCommitPowerUser"
    AWSCodeCommitFullAccess = "arn:aws:iam::aws:policy/AWSCodeCommitFullAccess"
    IAMSelfManageServiceSpecificCredentials = "arn:aws:iam::aws:policy/IAMSelfManageServiceSpecificCredentials"
    AmazonEMRCleanupPolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEMRCleanupPolicy"
    AWSCloud9EnvironmentMember = "arn:aws:iam::aws:policy/AWSCloud9EnvironmentMember"
    AWSApplicationAutoscalingSageMakerEndpointPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingSageMakerEndpointPolicy"
    FMSServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/FMSServiceRolePolicy"
    AmazonSQSFullAccess = "arn:aws:iam::aws:policy/AmazonSQSFullAccess"
    AlexaForBusinessReadOnlyAccess = "arn:aws:iam::aws:policy/AlexaForBusinessReadOnlyAccess"
    AWSIoTLogging = "arn:aws:iam::aws:policy/service-role/AWSIoTLogging"
    AmazonEC2RoleforSSM = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforSSM"
    AlexaForBusinessNetworkProfileServicePolicy = "arn:aws:iam::aws:policy/aws-service-role/AlexaForBusinessNetworkProfileServicePolicy"
    AWSCloudHSMRole = "arn:aws:iam::aws:policy/service-role/AWSCloudHSMRole"
    AWSEnhancedClassicNetworkingMangementPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSEnhancedClassicNetworkingMangementPolicy"
    IAMFullAccess = "arn:aws:iam::aws:policy/IAMFullAccess"
    AmazonInspectorFullAccess = "arn:aws:iam::aws:policy/AmazonInspectorFullAccess"
    AmazonElastiCacheFullAccess = "arn:aws:iam::aws:policy/AmazonElastiCacheFullAccess"
    AWSAgentlessDiscoveryService = "arn:aws:iam::aws:policy/AWSAgentlessDiscoveryService"
    AWSXrayWriteOnlyAccess = "arn:aws:iam::aws:policy/AWSXrayWriteOnlyAccess"
    AWSPriceListServiceFullAccess = "arn:aws:iam::aws:policy/AWSPriceListServiceFullAccess"
    AWSKeyManagementServiceCustomKeyStoresServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSKeyManagementServiceCustomKeyStoresServiceRolePolicy"
    AutoScalingReadOnlyAccess = "arn:aws:iam::aws:policy/AutoScalingReadOnlyAccess"
    AmazonForecastFullAccess = "arn:aws:iam::aws:policy/AmazonForecastFullAccess"
    AmazonWorkLinkReadOnly = "arn:aws:iam::aws:policy/AmazonWorkLinkReadOnly"
    TranslateFullAccess = "arn:aws:iam::aws:policy/TranslateFullAccess"
    AutoScalingFullAccess = "arn:aws:iam::aws:policy/AutoScalingFullAccess"
    AmazonEC2RoleforAWSCodeDeploy = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforAWSCodeDeploy"
    AWSFMMemberReadOnlyAccess = "arn:aws:iam::aws:policy/AWSFMMemberReadOnlyAccess"
    AmazonElasticMapReduceEditorsRole = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceEditorsRole"
    AmazonEKSClusterPolicy = "arn:aws:iam::aws:policy/AmazonEKSClusterPolicy"
    AmazonEKSWorkerNodePolicy = "arn:aws:iam::aws:policy/AmazonEKSWorkerNodePolicy"
    AWSMobileHub_ReadOnly = "arn:aws:iam::aws:policy/AWSMobileHub_ReadOnly"
    CloudWatchEventsBuiltInTargetExecutionAccess = "arn:aws:iam::aws:policy/service-role/CloudWatchEventsBuiltInTargetExecutionAccess"
    AutoScalingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AutoScalingServiceRolePolicy"
    AmazonElasticTranscoder_FullAccess = "arn:aws:iam::aws:policy/AmazonElasticTranscoder_FullAccess"
    AmazonCloudDirectoryReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonCloudDirectoryReadOnlyAccess"
    CloudWatchAgentAdminPolicy = "arn:aws:iam::aws:policy/CloudWatchAgentAdminPolicy"
    AWSOpsWorksCMInstanceProfileRole = "arn:aws:iam::aws:policy/AWSOpsWorksCMInstanceProfileRole"
    AWSBatchServiceEventTargetRole = "arn:aws:iam::aws:policy/service-role/AWSBatchServiceEventTargetRole"
    AWSCodePipelineApproverAccess = "arn:aws:iam::aws:policy/AWSCodePipelineApproverAccess"
    AWSApplicationDiscoveryAgentAccess = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryAgentAccess"
    ViewOnlyAccess = "arn:aws:iam::aws:policy/job-function/ViewOnlyAccess"
    AmazonElasticMapReduceRole = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceRole"
    ElasticLoadBalancingFullAccess = "arn:aws:iam::aws:policy/ElasticLoadBalancingFullAccess"
    AmazonRoute53DomainsReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53DomainsReadOnlyAccess"
    AmazonSSMAutomationApproverAccess = "arn:aws:iam::aws:policy/AmazonSSMAutomationApproverAccess"
    AWSSecurityHubReadOnlyAccess = "arn:aws:iam::aws:policy/AWSSecurityHubReadOnlyAccess"
    AWSConfigRoleForOrganizations = "arn:aws:iam::aws:policy/service-role/AWSConfigRoleForOrganizations"
    ApplicationAutoScalingForAmazonAppStreamAccess = "arn:aws:iam::aws:policy/service-role/ApplicationAutoScalingForAmazonAppStreamAccess"
    AmazonEC2ContainerRegistryFullAccess = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryFullAccess"
    AmazonFSxFullAccess = "arn:aws:iam::aws:policy/AmazonFSxFullAccess"
    SimpleWorkflowFullAccess = "arn:aws:iam::aws:policy/SimpleWorkflowFullAccess"
    GreengrassOTAUpdateArtifactAccess = "arn:aws:iam::aws:policy/service-role/GreengrassOTAUpdateArtifactAccess"
    AmazonS3FullAccess = "arn:aws:iam::aws:policy/AmazonS3FullAccess"
    AWSStorageGatewayReadOnlyAccess = "arn:aws:iam::aws:policy/AWSStorageGatewayReadOnlyAccess"
    Billing = "arn:aws:iam::aws:policy/job-function/Billing"
    QuickSightAccessForS3StorageManagementAnalyticsReadOnly = "arn:aws:iam::aws:policy/service-role/QuickSightAccessForS3StorageManagementAnalyticsReadOnly"
    AmazonEC2ContainerRegistryReadOnly = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryReadOnly"
    AmazonElasticMapReduceforEC2Role = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforEC2Role"
    DatabaseAdministrator = "arn:aws:iam::aws:policy/job-function/DatabaseAdministrator"
    AmazonRedshiftReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRedshiftReadOnlyAccess"
    AmazonEC2ReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonEC2ReadOnlyAccess"
    CloudWatchAgentServerPolicy = "arn:aws:iam::aws:policy/CloudWatchAgentServerPolicy"
    AWSXrayReadOnlyAccess = "arn:aws:iam::aws:policy/AWSXrayReadOnlyAccess"
    AWSElasticBeanstalkEnhancedHealth = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkEnhancedHealth"
    WellArchitectedConsoleFullAccess = "arn:aws:iam::aws:policy/WellArchitectedConsoleFullAccess"
    AmazonElasticMapReduceReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonElasticMapReduceReadOnlyAccess"
    AWSDirectoryServiceReadOnlyAccess = "arn:aws:iam::aws:policy/AWSDirectoryServiceReadOnlyAccess"
    AWSSSOMasterAccountAdministrator = "arn:aws:iam::aws:policy/AWSSSOMasterAccountAdministrator"
    AmazonGuardDutyServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonGuardDutyServiceRolePolicy"
    AmazonVPCReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonVPCReadOnlyAccess"
    AWSElasticBeanstalkServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticBeanstalkServiceRolePolicy"
    ServerMigrationServiceLaunchRole = "arn:aws:iam::aws:policy/service-role/ServerMigrationServiceLaunchRole"
    AWSCodeDeployRoleForECS = "arn:aws:iam::aws:policy/AWSCodeDeployRoleForECS"
    CloudWatchEventsReadOnlyAccess = "arn:aws:iam::aws:policy/CloudWatchEventsReadOnlyAccess"
    AWSLambdaReplicator = "arn:aws:iam::aws:policy/aws-service-role/AWSLambdaReplicator"
    AmazonAPIGatewayInvokeFullAccess = "arn:aws:iam::aws:policy/AmazonAPIGatewayInvokeFullAccess"
    AWSSSOServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSSOServiceRolePolicy"
    AWSLicenseManagerMasterAccountRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerMasterAccountRolePolicy"
    AmazonKinesisAnalyticsReadOnly = "arn:aws:iam::aws:policy/AmazonKinesisAnalyticsReadOnly"
    AmazonMobileAnalyticsFullAccess = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsFullAccess"
    AWSMobileHub_FullAccess = "arn:aws:iam::aws:policy/AWSMobileHub_FullAccess"
    AmazonAPIGatewayPushToCloudWatchLogs = "arn:aws:iam::aws:policy/service-role/AmazonAPIGatewayPushToCloudWatchLogs"
    AWSDataPipelineRole = "arn:aws:iam::aws:policy/service-role/AWSDataPipelineRole"
    CloudWatchFullAccess = "arn:aws:iam::aws:policy/CloudWatchFullAccess"
    AmazonMQApiReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMQApiReadOnlyAccess"
    AWSDeepLensLambdaFunctionAccessPolicy = "arn:aws:iam::aws:policy/AWSDeepLensLambdaFunctionAccessPolicy"
    AmazonGuardDutyFullAccess = "arn:aws:iam::aws:policy/AmazonGuardDutyFullAccess"
    AmazonRDSDirectoryServiceAccess = "arn:aws:iam::aws:policy/service-role/AmazonRDSDirectoryServiceAccess"
    AWSCodePipelineReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCodePipelineReadOnlyAccess"
    ReadOnlyAccess = "arn:aws:iam::aws:policy/ReadOnlyAccess"
    AWSAppSyncInvokeFullAccess = "arn:aws:iam::aws:policy/AWSAppSyncInvokeFullAccess"
    AmazonMachineLearningBatchPredictionsAccess = "arn:aws:iam::aws:policy/AmazonMachineLearningBatchPredictionsAccess"
    AWSIoTSiteWiseFullAccess = "arn:aws:iam::aws:policy/AWSIoTSiteWiseFullAccess"
    AlexaForBusinessFullAccess = "arn:aws:iam::aws:policy/AlexaForBusinessFullAccess"
    AWSEC2SpotFleetServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2SpotFleetServiceRolePolicy"
    AmazonRekognitionReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRekognitionReadOnlyAccess"
    AWSCodeDeployReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCodeDeployReadOnlyAccess"
    CloudSearchFullAccess = "arn:aws:iam::aws:policy/CloudSearchFullAccess"
    AWSLicenseManagerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerServiceRolePolicy"
    AWSCloudHSMFullAccess = "arn:aws:iam::aws:policy/AWSCloudHSMFullAccess"
    AmazonEC2SpotFleetAutoscaleRole = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetAutoscaleRole"
    AWSElasticLoadBalancingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticLoadBalancingServiceRolePolicy"
    AWSCodeBuildDeveloperAccess = "arn:aws:iam::aws:policy/AWSCodeBuildDeveloperAccess"
    ElastiCacheServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ElastiCacheServiceRolePolicy"
    AWSGlueServiceNotebookRole = "arn:aws:iam::aws:policy/service-role/AWSGlueServiceNotebookRole"
    AWSDataPipeline_PowerUser = "arn:aws:iam::aws:policy/AWSDataPipeline_PowerUser"
    AWSCodeStarServiceRole = "arn:aws:iam::aws:policy/service-role/AWSCodeStarServiceRole"
    AmazonTranscribeFullAccess = "arn:aws:iam::aws:policy/AmazonTranscribeFullAccess"
    AWSDirectoryServiceFullAccess = "arn:aws:iam::aws:policy/AWSDirectoryServiceFullAccess"
    AmazonFreeRTOSOTAUpdate = "arn:aws:iam::aws:policy/service-role/AmazonFreeRTOSOTAUpdate"
    AmazonWorkLinkServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonWorkLinkServiceRolePolicy"
    AmazonDynamoDBFullAccess = "arn:aws:iam::aws:policy/AmazonDynamoDBFullAccess"
    AmazonSESReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonSESReadOnlyAccess"
    AmazonRedshiftQueryEditor = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditor"
    AWSWAFReadOnlyAccess = "arn:aws:iam::aws:policy/AWSWAFReadOnlyAccess"
    AutoScalingNotificationAccessRole = "arn:aws:iam::aws:policy/service-role/AutoScalingNotificationAccessRole"
    AmazonMechanicalTurkReadOnly = "arn:aws:iam::aws:policy/AmazonMechanicalTurkReadOnly"
    AmazonKinesisReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonKinesisReadOnlyAccess"
    AWSXRayDaemonWriteAccess = "arn:aws:iam::aws:policy/AWSXRayDaemonWriteAccess"
    AWSCloudMapReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCloudMapReadOnlyAccess"
    AWSCloudFrontLogger = "arn:aws:iam::aws:policy/aws-service-role/AWSCloudFrontLogger"
    AWSCodeDeployFullAccess = "arn:aws:iam::aws:policy/AWSCodeDeployFullAccess"
    AWSBackupServiceRolePolicyForBackup = "arn:aws:iam::aws:policy/service-role/AWSBackupServiceRolePolicyForBackup"
    AWSRoboMakerServiceRolePolicy = "arn:aws:iam::aws:policy/AWSRoboMakerServiceRolePolicy"
    CloudWatchActionsEC2Access = "arn:aws:iam::aws:policy/CloudWatchActionsEC2Access"
    AWSLambdaDynamoDBExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaDynamoDBExecutionRole"
    AmazonRoute53DomainsFullAccess = "arn:aws:iam::aws:policy/AmazonRoute53DomainsFullAccess"
    AmazonElastiCacheReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonElastiCacheReadOnlyAccess"
    AmazonRDSServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSServiceRolePolicy"
    AmazonAthenaFullAccess = "arn:aws:iam::aws:policy/AmazonAthenaFullAccess"
    AmazonElasticFileSystemReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonElasticFileSystemReadOnlyAccess"
    AWSCloudMapDiscoverInstanceAccess = "arn:aws:iam::aws:policy/AWSCloudMapDiscoverInstanceAccess"
    CloudFrontFullAccess = "arn:aws:iam::aws:policy/CloudFrontFullAccess"
    AWSCloud9Administrator = "arn:aws:iam::aws:policy/AWSCloud9Administrator"
    AWSApplicationAutoscalingEMRInstanceGroupPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingEMRInstanceGroupPolicy"
    AmazonTextractFullAccess = "arn:aws:iam::aws:policy/AmazonTextractFullAccess"
    AWSOrganizationsServiceTrustPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSOrganizationsServiceTrustPolicy"
    AmazonDocDBFullAccess = "arn:aws:iam::aws:policy/AmazonDocDBFullAccess"
    AmazonMobileAnalyticsNon_financialReportAccess = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsNon-financialReportAccess"
    AmazonCognitoDeveloperAuthenticatedIdentities = "arn:aws:iam::aws:policy/AmazonCognitoDeveloperAuthenticatedIdentities"
    AWSConfigRole = "arn:aws:iam::aws:policy/service-role/AWSConfigRole"
    AWSSSOMemberAccountAdministrator = "arn:aws:iam::aws:policy/AWSSSOMemberAccountAdministrator"
    AWSApplicationAutoscalingAppStreamFleetPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingAppStreamFleetPolicy"
    IsengardControllerPolicy = "arn:aws:iam::aws:policy/aws-service-role/IsengardControllerPolicy"
    AWSCertificateManagerPrivateCAFullAccess = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAFullAccess"
    AWSGlueServiceRole = "arn:aws:iam::aws:policy/service-role/AWSGlueServiceRole"
    AmazonAppStreamServiceAccess = "arn:aws:iam::aws:policy/service-role/AmazonAppStreamServiceAccess"
    AmazonRedshiftFullAccess = "arn:aws:iam::aws:policy/AmazonRedshiftFullAccess"
    AWSTransferLoggingAccess = "arn:aws:iam::aws:policy/service-role/AWSTransferLoggingAccess"
    AmazonZocaloReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonZocaloReadOnlyAccess"
    AWSCloudHSMReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCloudHSMReadOnlyAccess"
    ComprehendFullAccess = "arn:aws:iam::aws:policy/ComprehendFullAccess"
    AmazonFSxConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonFSxConsoleFullAccess"
    SystemAdministrator = "arn:aws:iam::aws:policy/job-function/SystemAdministrator"
    AmazonEC2ContainerServiceEventsRole = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceEventsRole"
    AmazonRoute53ReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53ReadOnlyAccess"
    AWSMigrationHubDiscoveryAccess = "arn:aws:iam::aws:policy/service-role/AWSMigrationHubDiscoveryAccess"
    AmazonEC2ContainerServiceAutoscaleRole = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceAutoscaleRole"
    AWSAppSyncSchemaAuthor = "arn:aws:iam::aws:policy/AWSAppSyncSchemaAuthor"
    AlexaForBusinessDeviceSetup = "arn:aws:iam::aws:policy/AlexaForBusinessDeviceSetup"
    AWSBatchServiceRole = "arn:aws:iam::aws:policy/service-role/AWSBatchServiceRole"
    AWSElasticBeanstalkWebTier = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWebTier"
    AmazonSQSReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonSQSReadOnlyAccess"
    AmazonChimeFullAccess = "arn:aws:iam::aws:policy/AmazonChimeFullAccess"
    AWSDeepRacerRoboMakerAccessPolicy = "arn:aws:iam::aws:policy/AWSDeepRacerRoboMakerAccessPolicy"
    AWSElasticLoadBalancingClassicServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticLoadBalancingClassicServiceRolePolicy"
    AWSMigrationHubDMSAccess = "arn:aws:iam::aws:policy/service-role/AWSMigrationHubDMSAccess"
    WellArchitectedConsoleReadOnlyAccess = "arn:aws:iam::aws:policy/WellArchitectedConsoleReadOnlyAccess"
    AmazonKinesisFullAccess = "arn:aws:iam::aws:policy/AmazonKinesisFullAccess"
    AmazonGuardDutyReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonGuardDutyReadOnlyAccess"
    AmazonFSxServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonFSxServiceRolePolicy"
    AmazonECSServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonECSServiceRolePolicy"
    AmazonConnectReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonConnectReadOnlyAccess"
    AmazonMachineLearningReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMachineLearningReadOnlyAccess"
    AmazonRekognitionFullAccess = "arn:aws:iam::aws:policy/AmazonRekognitionFullAccess"
    RDSCloudHsmAuthorizationRole = "arn:aws:iam::aws:policy/service-role/RDSCloudHsmAuthorizationRole"
    AmazonMachineLearningFullAccess = "arn:aws:iam::aws:policy/AmazonMachineLearningFullAccess"
    AdministratorAccess = "arn:aws:iam::aws:policy/AdministratorAccess"
    AmazonMachineLearningRealTimePredictionOnlyAccess = "arn:aws:iam::aws:policy/AmazonMachineLearningRealTimePredictionOnlyAccess"
    AWSAppSyncPushToCloudWatchLogs = "arn:aws:iam::aws:policy/service-role/AWSAppSyncPushToCloudWatchLogs"
    AWSMigrationHubSMSAccess = "arn:aws:iam::aws:policy/service-role/AWSMigrationHubSMSAccess"
    AWSConfigUserAccess = "arn:aws:iam::aws:policy/AWSConfigUserAccess"
    AWSIoTConfigAccess = "arn:aws:iam::aws:policy/AWSIoTConfigAccess"
    SecurityAudit = "arn:aws:iam::aws:policy/SecurityAudit"
    AWSDiscoveryContinuousExportFirehosePolicy = "arn:aws:iam::aws:policy/AWSDiscoveryContinuousExportFirehosePolicy"
    AmazonCognitoIdpEmailServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonCognitoIdpEmailServiceRolePolicy"
    AWSElementalMediaConvertFullAccess = "arn:aws:iam::aws:policy/AWSElementalMediaConvertFullAccess"
    AWSRoboMakerReadOnlyAccess = "arn:aws:iam::aws:policy/AWSRoboMakerReadOnlyAccess"
    AWSResourceGroupsReadOnlyAccess = "arn:aws:iam::aws:policy/AWSResourceGroupsReadOnlyAccess"
    AWSCodeStarFullAccess = "arn:aws:iam::aws:policy/AWSCodeStarFullAccess"
    AmazonSSMServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonSSMServiceRolePolicy"
    AWSDataPipeline_FullAccess = "arn:aws:iam::aws:policy/AWSDataPipeline_FullAccess"
    NeptuneFullAccess = "arn:aws:iam::aws:policy/NeptuneFullAccess"
    AmazonSSMManagedInstanceCore = "arn:aws:iam::aws:policy/AmazonSSMManagedInstanceCore"
    AWSAutoScalingPlansEC2AutoScalingPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSAutoScalingPlansEC2AutoScalingPolicy"
    AmazonDynamoDBReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonDynamoDBReadOnlyAccess"
    AutoScalingConsoleFullAccess = "arn:aws:iam::aws:policy/AutoScalingConsoleFullAccess"
    AWSElementalMediaPackageFullAccess = "arn:aws:iam::aws:policy/AWSElementalMediaPackageFullAccess"
    AmazonKinesisVideoStreamsFullAccess = "arn:aws:iam::aws:policy/AmazonKinesisVideoStreamsFullAccess"
    AmazonSNSReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonSNSReadOnlyAccess"
    AmazonRDSPreviewServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSPreviewServiceRolePolicy"
    AWSEC2SpotServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2SpotServiceRolePolicy"
    AmazonElasticMapReduceFullAccess = "arn:aws:iam::aws:policy/AmazonElasticMapReduceFullAccess"
    AWSCloudMapFullAccess = "arn:aws:iam::aws:policy/AWSCloudMapFullAccess"
    AWSDataLifecycleManagerServiceRole = "arn:aws:iam::aws:policy/service-role/AWSDataLifecycleManagerServiceRole"
    AmazonS3ReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonS3ReadOnlyAccess"
    AmazonWorkSpacesAdmin = "arn:aws:iam::aws:policy/AmazonWorkSpacesAdmin"
    AWSCodeDeployRole = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRole"
    AmazonSESFullAccess = "arn:aws:iam::aws:policy/AmazonSESFullAccess"
    CloudWatchLogsReadOnlyAccess = "arn:aws:iam::aws:policy/CloudWatchLogsReadOnlyAccess"
    AmazonRDSBetaServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSBetaServiceRolePolicy"
    AmazonKinesisFirehoseReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonKinesisFirehoseReadOnlyAccess"
    GlobalAcceleratorFullAccess = "arn:aws:iam::aws:policy/GlobalAcceleratorFullAccess"
    AmazonDynamoDBFullAccesswithDataPipeline = "arn:aws:iam::aws:policy/AmazonDynamoDBFullAccesswithDataPipeline"
    AWSIoTAnalyticsReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIoTAnalyticsReadOnlyAccess"
    AmazonEC2RoleforDataPipelineRole = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforDataPipelineRole"
    CloudWatchLogsFullAccess = "arn:aws:iam::aws:policy/CloudWatchLogsFullAccess"
    AWSSecurityHubFullAccess = "arn:aws:iam::aws:policy/AWSSecurityHubFullAccess"
    AWSElementalMediaPackageReadOnly = "arn:aws:iam::aws:policy/AWSElementalMediaPackageReadOnly"
    AWSElasticBeanstalkMulticontainerDocker = "arn:aws:iam::aws:policy/AWSElasticBeanstalkMulticontainerDocker"
    AmazonPersonalizeFullAccess = "arn:aws:iam::aws:policy/service-role/AmazonPersonalizeFullAccess"
    AWSMigrationHubFullAccess = "arn:aws:iam::aws:policy/AWSMigrationHubFullAccess"
    AmazonFSxReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonFSxReadOnlyAccess"
    IAMUserChangePassword = "arn:aws:iam::aws:policy/IAMUserChangePassword"
    LightsailExportAccess = "arn:aws:iam::aws:policy/aws-service-role/LightsailExportAccess"
    AmazonAPIGatewayAdministrator = "arn:aws:iam::aws:policy/AmazonAPIGatewayAdministrator"
    AmazonVPCCrossAccountNetworkInterfaceOperations = "arn:aws:iam::aws:policy/AmazonVPCCrossAccountNetworkInterfaceOperations"
    AmazonMacieSetupRole = "arn:aws:iam::aws:policy/service-role/AmazonMacieSetupRole"
    AmazonPollyReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonPollyReadOnlyAccess"
    AmazonRDSDataFullAccess = "arn:aws:iam::aws:policy/AmazonRDSDataFullAccess"
    AmazonMobileAnalyticsWriteOnlyAccess = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsWriteOnlyAccess"
    AmazonEC2SpotFleetTaggingRole = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetTaggingRole"
    DataScientist = "arn:aws:iam::aws:policy/job-function/DataScientist"
    AWSMarketplaceMeteringFullAccess = "arn:aws:iam::aws:policy/AWSMarketplaceMeteringFullAccess"
    AWSOpsWorksCMServiceRole = "arn:aws:iam::aws:policy/service-role/AWSOpsWorksCMServiceRole"
    FSxDeleteServiceLinkedRoleAccess = "arn:aws:iam::aws:policy/aws-service-role/FSxDeleteServiceLinkedRoleAccess"
    WorkLinkServiceRolePolicy = "arn:aws:iam::aws:policy/WorkLinkServiceRolePolicy"
    AmazonConnectServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonConnectServiceLinkedRolePolicy"
    AWSPrivateMarketplaceAdminFullAccess = "arn:aws:iam::aws:policy/AWSPrivateMarketplaceAdminFullAccess"
    AWSConnector = "arn:aws:iam::aws:policy/AWSConnector"
    AWSCodeDeployRoleForECSLimited = "arn:aws:iam::aws:policy/AWSCodeDeployRoleForECSLimited"
    AmazonElasticTranscoder_JobsSubmitter = "arn:aws:iam::aws:policy/AmazonElasticTranscoder_JobsSubmitter"
    AmazonMacieHandshakeRole = "arn:aws:iam::aws:policy/service-role/AmazonMacieHandshakeRole"
    AWSIoTAnalyticsFullAccess = "arn:aws:iam::aws:policy/AWSIoTAnalyticsFullAccess"
    AWSBatchFullAccess = "arn:aws:iam::aws:policy/AWSBatchFullAccess"
    AmazonSSMDirectoryServiceAccess = "arn:aws:iam::aws:policy/AmazonSSMDirectoryServiceAccess"
    AmazonECS_FullAccess = "arn:aws:iam::aws:policy/AmazonECS_FullAccess"
    AWSSupportServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSupportServiceRolePolicy"
    AWSApplicationAutoscalingRDSClusterPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingRDSClusterPolicy"
    AWSServiceRoleForEC2ScheduledInstances = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForEC2ScheduledInstances"
    AWSCodeDeployRoleForLambda = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRoleForLambda"
    AWSFMAdminReadOnlyAccess = "arn:aws:iam::aws:policy/AWSFMAdminReadOnlyAccess"
    AmazonSSMFullAccess = "arn:aws:iam::aws:policy/AmazonSSMFullAccess"
    AWSCodeCommitReadOnly = "arn:aws:iam::aws:policy/AWSCodeCommitReadOnly"
    AmazonFreeRTOSFullAccess = "arn:aws:iam::aws:policy/AmazonFreeRTOSFullAccess"
    AmazonTextractServiceRole = "arn:aws:iam::aws:policy/service-role/AmazonTextractServiceRole"
    AmazonCognitoReadOnly = "arn:aws:iam::aws:policy/AmazonCognitoReadOnly"
    AmazonDMSCloudWatchLogsRole = "arn:aws:iam::aws:policy/service-role/AmazonDMSCloudWatchLogsRole"
    AWSApplicationDiscoveryServiceFullAccess = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryServiceFullAccess"
    AmazonRoute53AutoNamingReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53AutoNamingReadOnlyAccess"
    AWSSSOReadOnly = "arn:aws:iam::aws:policy/AWSSSOReadOnly"
    AmazonVPCFullAccess = "arn:aws:iam::aws:policy/AmazonVPCFullAccess"
    AWSCertificateManagerPrivateCAUser = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAUser"
    AWSAppSyncAdministrator = "arn:aws:iam::aws:policy/AWSAppSyncAdministrator"
    AWSEC2FleetServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2FleetServiceRolePolicy"
    AmazonRoute53AutoNamingFullAccess = "arn:aws:iam::aws:policy/AmazonRoute53AutoNamingFullAccess"
    AWSImportExportFullAccess = "arn:aws:iam::aws:policy/AWSImportExportFullAccess"
    DynamoDBReplicationServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/DynamoDBReplicationServiceRolePolicy"
    AmazonMechanicalTurkFullAccess = "arn:aws:iam::aws:policy/AmazonMechanicalTurkFullAccess"
    AmazonEC2ContainerRegistryPowerUser = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryPowerUser"
    AWSSSODirectoryReadOnly = "arn:aws:iam::aws:policy/AWSSSODirectoryReadOnly"
    AmazonMachineLearningCreateOnlyAccess = "arn:aws:iam::aws:policy/AmazonMachineLearningCreateOnlyAccess"
    AmazonKinesisVideoStreamsReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonKinesisVideoStreamsReadOnlyAccess"
    AWSCloudTrailReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCloudTrailReadOnlyAccess"
    WAFRegionalLoggingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/WAFRegionalLoggingServiceRolePolicy"
    AWSLambdaExecute = "arn:aws:iam::aws:policy/AWSLambdaExecute"
    AWSGlueConsoleSageMakerNotebookFullAccess = "arn:aws:iam::aws:policy/AWSGlueConsoleSageMakerNotebookFullAccess"
    AmazonMSKFullAccess = "arn:aws:iam::aws:policy/AmazonMSKFullAccess"
    AWSIoTRuleActions = "arn:aws:iam::aws:policy/service-role/AWSIoTRuleActions"
    AmazonEKSServicePolicy = "arn:aws:iam::aws:policy/AmazonEKSServicePolicy"
    AWSQuickSightDescribeRedshift = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRedshift"
    AmazonElasticsearchServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonElasticsearchServiceRolePolicy"
    AmazonMQReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMQReadOnlyAccess"
    VMImportExportRoleForAWSConnector = "arn:aws:iam::aws:policy/service-role/VMImportExportRoleForAWSConnector"
    AWSCodePipelineCustomActionAccess = "arn:aws:iam::aws:policy/AWSCodePipelineCustomActionAccess"
    AWSLambdaSQSQueueExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaSQSQueueExecutionRole"
    AWSCloud9ServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSCloud9ServiceRolePolicy"
    AWSApplicationAutoscalingECSServicePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingECSServicePolicy"
    AWSOpsWorksInstanceRegistration = "arn:aws:iam::aws:policy/AWSOpsWorksInstanceRegistration"
    AmazonCloudDirectoryFullAccess = "arn:aws:iam::aws:policy/AmazonCloudDirectoryFullAccess"
    AmazonECSTaskExecutionRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonECSTaskExecutionRolePolicy"
    AWSStorageGatewayFullAccess = "arn:aws:iam::aws:policy/AWSStorageGatewayFullAccess"
    AWSIoTEventsFullAccess = "arn:aws:iam::aws:policy/AWSIoTEventsFullAccess"
    AmazonLexReadOnly = "arn:aws:iam::aws:policy/AmazonLexReadOnly"
    AmazonChimeUserManagement = "arn:aws:iam::aws:policy/AmazonChimeUserManagement"
    AmazonMSKReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMSKReadOnlyAccess"
    AWSDataSyncFullAccess = "arn:aws:iam::aws:policy/AWSDataSyncFullAccess"
    AWSServiceRoleForIoTSiteWise = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForIoTSiteWise"
    CloudwatchApplicationInsightsServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CloudwatchApplicationInsightsServiceLinkedRolePolicy"
    AWSTrustedAdvisorServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSTrustedAdvisorServiceRolePolicy"
    AWSIoTConfigReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIoTConfigReadOnlyAccess"
    AmazonWorkMailReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonWorkMailReadOnlyAccess"
    AmazonDMSVPCManagementRole = "arn:aws:iam::aws:policy/service-role/AmazonDMSVPCManagementRole"
    AWSLambdaKinesisExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaKinesisExecutionRole"
    ComprehendDataAccessRolePolicy = "arn:aws:iam::aws:policy/service-role/ComprehendDataAccessRolePolicy"
    AmazonDocDBConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonDocDBConsoleFullAccess"
    ResourceGroupsandTagEditorReadOnlyAccess = "arn:aws:iam::aws:policy/ResourceGroupsandTagEditorReadOnlyAccess"
    AmazonRekognitionServiceRole = "arn:aws:iam::aws:policy/service-role/AmazonRekognitionServiceRole"
    AmazonSSMAutomationRole = "arn:aws:iam::aws:policy/service-role/AmazonSSMAutomationRole"
    CloudHSMServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CloudHSMServiceRolePolicy"
    ComprehendReadOnly = "arn:aws:iam::aws:policy/ComprehendReadOnly"
    AWSStepFunctionsConsoleFullAccess = "arn:aws:iam::aws:policy/AWSStepFunctionsConsoleFullAccess"
    AWSQuickSightIoTAnalyticsAccess = "arn:aws:iam::aws:policy/AWSQuickSightIoTAnalyticsAccess"
    AWSCodeBuildReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCodeBuildReadOnlyAccess"
    LexBotPolicy = "arn:aws:iam::aws:policy/aws-service-role/LexBotPolicy"
    AmazonMacieFullAccess = "arn:aws:iam::aws:policy/AmazonMacieFullAccess"
    AmazonMachineLearningManageRealTimeEndpointOnlyAccess = "arn:aws:iam::aws:policy/AmazonMachineLearningManageRealTimeEndpointOnlyAccess"
    CloudWatchEventsInvocationAccess = "arn:aws:iam::aws:policy/service-role/CloudWatchEventsInvocationAccess"
    CloudFrontReadOnlyAccess = "arn:aws:iam::aws:policy/CloudFrontReadOnlyAccess"
    AWSDeepLensServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSDeepLensServiceRolePolicy"
    AmazonSNSRole = "arn:aws:iam::aws:policy/service-role/AmazonSNSRole"
    AmazonInspectorServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonInspectorServiceRolePolicy"
    AmazonMobileAnalyticsFinancialReportAccess = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsFinancialReportAccess"
    AWSElasticBeanstalkService = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkService"
    IAMReadOnlyAccess = "arn:aws:iam::aws:policy/IAMReadOnlyAccess"
    AmazonRDSReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRDSReadOnlyAccess"
    AWSIoTDeviceDefenderAudit = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderAudit"
    AmazonCognitoPowerUser = "arn:aws:iam::aws:policy/AmazonCognitoPowerUser"
    AmazonRoute53AutoNamingRegistrantAccess = "arn:aws:iam::aws:policy/AmazonRoute53AutoNamingRegistrantAccess"
    AmazonElasticFileSystemFullAccess = "arn:aws:iam::aws:policy/AmazonElasticFileSystemFullAccess"
    LexChannelPolicy = "arn:aws:iam::aws:policy/aws-service-role/LexChannelPolicy"
    ServerMigrationConnector = "arn:aws:iam::aws:policy/ServerMigrationConnector"
    AmazonESCognitoAccess = "arn:aws:iam::aws:policy/AmazonESCognitoAccess"
    AWSFMAdminFullAccess = "arn:aws:iam::aws:policy/AWSFMAdminFullAccess"
    AmazonChimeReadOnly = "arn:aws:iam::aws:policy/AmazonChimeReadOnly"
    AmazonZocaloFullAccess = "arn:aws:iam::aws:policy/AmazonZocaloFullAccess"
    AWSIoTSiteWiseReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIoTSiteWiseReadOnlyAccess"
    AWSAccountUsageReportAccess = "arn:aws:iam::aws:policy/AWSAccountUsageReportAccess"
    AWSIoTOTAUpdate = "arn:aws:iam::aws:policy/service-role/AWSIoTOTAUpdate"
    AmazonMQFullAccess = "arn:aws:iam::aws:policy/AmazonMQFullAccess"
    AWSMarketplaceGetEntitlements = "arn:aws:iam::aws:policy/AWSMarketplaceGetEntitlements"
    AWSGreengrassReadOnlyAccess = "arn:aws:iam::aws:policy/AWSGreengrassReadOnlyAccess"
    AmazonEC2ContainerServiceforEC2Role = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceforEC2Role"
    AmazonAppStreamFullAccess = "arn:aws:iam::aws:policy/AmazonAppStreamFullAccess"
    AWSIoTDataAccess = "arn:aws:iam::aws:policy/AWSIoTDataAccess"
    AmazonWorkLinkFullAccess = "arn:aws:iam::aws:policy/AmazonWorkLinkFullAccess"
    AmazonTranscribeReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonTranscribeReadOnlyAccess"
    AmazonESFullAccess = "arn:aws:iam::aws:policy/AmazonESFullAccess"
    ApplicationDiscoveryServiceContinuousExportServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ApplicationDiscoveryServiceContinuousExportServiceRolePolicy"
    AmazonSumerianFullAccess = "arn:aws:iam::aws:policy/AmazonSumerianFullAccess"
    AWSWAFFullAccess = "arn:aws:iam::aws:policy/AWSWAFFullAccess"
    ElasticLoadBalancingReadOnly = "arn:aws:iam::aws:policy/ElasticLoadBalancingReadOnly"
    AWSArtifactAccountSync = "arn:aws:iam::aws:policy/service-role/AWSArtifactAccountSync"
    AmazonKinesisFirehoseFullAccess = "arn:aws:iam::aws:policy/AmazonKinesisFirehoseFullAccess"
    CloudWatchReadOnlyAccess = "arn:aws:iam::aws:policy/CloudWatchReadOnlyAccess"
    AWSLambdaBasicExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaBasicExecutionRole"
    ResourceGroupsandTagEditorFullAccess = "arn:aws:iam::aws:policy/ResourceGroupsandTagEditorFullAccess"
    AWSKeyManagementServicePowerUser = "arn:aws:iam::aws:policy/AWSKeyManagementServicePowerUser"
    AWSApplicationAutoscalingEC2SpotFleetRequestPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingEC2SpotFleetRequestPolicy"
    AWSImportExportReadOnlyAccess = "arn:aws:iam::aws:policy/AWSImportExportReadOnlyAccess"
    CloudWatchEventsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CloudWatchEventsServiceRolePolicy"
    AmazonElasticTranscoderRole = "arn:aws:iam::aws:policy/service-role/AmazonElasticTranscoderRole"
    AWSGlueConsoleFullAccess = "arn:aws:iam::aws:policy/AWSGlueConsoleFullAccess"
    AmazonEC2ContainerServiceRole = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceRole"
    AWSDeviceFarmFullAccess = "arn:aws:iam::aws:policy/AWSDeviceFarmFullAccess"
    AmazonSSMReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonSSMReadOnlyAccess"
    AWSStepFunctionsReadOnlyAccess = "arn:aws:iam::aws:policy/AWSStepFunctionsReadOnlyAccess"
    AWSMarketplaceRead_only = "arn:aws:iam::aws:policy/AWSMarketplaceRead-only"
    AWSApplicationAutoscalingDynamoDBTablePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingDynamoDBTablePolicy"
    AWSCodePipelineFullAccess = "arn:aws:iam::aws:policy/AWSCodePipelineFullAccess"
    AWSCloud9User = "arn:aws:iam::aws:policy/AWSCloud9User"
    AWSGreengrassResourceAccessRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSGreengrassResourceAccessRolePolicy"
    AmazonMacieServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonMacieServiceRolePolicy"
    NetworkAdministrator = "arn:aws:iam::aws:policy/job-function/NetworkAdministrator"
    AWSIoT1ClickFullAccess = "arn:aws:iam::aws:policy/AWSIoT1ClickFullAccess"
    AmazonWorkSpacesApplicationManagerAdminAccess = "arn:aws:iam::aws:policy/AmazonWorkSpacesApplicationManagerAdminAccess"
    AmazonDRSVPCManagement = "arn:aws:iam::aws:policy/AmazonDRSVPCManagement"
    AmazonRedshiftServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonRedshiftServiceLinkedRolePolicy"
    AWSCertificateManagerPrivateCAReadOnly = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAReadOnly"
    AWSXrayFullAccess = "arn:aws:iam::aws:policy/AWSXrayFullAccess"
    AWSElasticBeanstalkWorkerTier = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWorkerTier"
    AWSDirectConnectFullAccess = "arn:aws:iam::aws:policy/AWSDirectConnectFullAccess"
    AWSCodeBuildAdminAccess = "arn:aws:iam::aws:policy/AWSCodeBuildAdminAccess"
    AmazonKinesisAnalyticsFullAccess = "arn:aws:iam::aws:policy/AmazonKinesisAnalyticsFullAccess"
    AWSSecurityHubServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSecurityHubServiceRolePolicy"
    AWSElasticBeanstalkMaintenance = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticBeanstalkMaintenance"
    APIGatewayServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/APIGatewayServiceRolePolicy"
    AWSAccountActivityAccess = "arn:aws:iam::aws:policy/AWSAccountActivityAccess"
    AmazonGlacierFullAccess = "arn:aws:iam::aws:policy/AmazonGlacierFullAccess"
    AmazonFSxConsoleReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonFSxConsoleReadOnlyAccess"
    AmazonWorkMailFullAccess = "arn:aws:iam::aws:policy/AmazonWorkMailFullAccess"
    DAXServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/DAXServiceRolePolicy"
    ComprehendMedicalFullAccess = "arn:aws:iam::aws:policy/ComprehendMedicalFullAccess"
    AWSMarketplaceManageSubscriptions = "arn:aws:iam::aws:policy/AWSMarketplaceManageSubscriptions"
    AWSElasticBeanstalkCustomPlatformforEC2Role = "arn:aws:iam::aws:policy/AWSElasticBeanstalkCustomPlatformforEC2Role"
    AWSDataSyncReadOnlyAccess = "arn:aws:iam::aws:policy/AWSDataSyncReadOnlyAccess"
    AWSVPCTransitGatewayServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSVPCTransitGatewayServiceRolePolicy"
    NeptuneReadOnlyAccess = "arn:aws:iam::aws:policy/NeptuneReadOnlyAccess"
    AWSSupportAccess = "arn:aws:iam::aws:policy/AWSSupportAccess"
    AmazonElasticMapReduceforAutoScalingRole = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforAutoScalingRole"
    AWSElementalMediaConvertReadOnly = "arn:aws:iam::aws:policy/AWSElementalMediaConvertReadOnly"
    AWSLambdaInvocation_DynamoDB = "arn:aws:iam::aws:policy/AWSLambdaInvocation-DynamoDB"
    AWSServiceCatalogEndUserFullAccess = "arn:aws:iam::aws:policy/AWSServiceCatalogEndUserFullAccess"
    IAMUserSSHKeys = "arn:aws:iam::aws:policy/IAMUserSSHKeys"
    AWSDeepRacerServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSDeepRacerServiceRolePolicy"
    AmazonSageMakerReadOnly = "arn:aws:iam::aws:policy/AmazonSageMakerReadOnly"
    AWSIoTFullAccess = "arn:aws:iam::aws:policy/AWSIoTFullAccess"
    AWSQuickSightDescribeRDS = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRDS"
    AWSResourceAccessManagerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSResourceAccessManagerServiceRolePolicy"
    AWSConfigRulesExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSConfigRulesExecutionRole"
    AWSConfigServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSConfigServiceRolePolicy"
    AmazonESReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonESReadOnlyAccess"
    AWSCodeDeployDeployerAccess = "arn:aws:iam::aws:policy/AWSCodeDeployDeployerAccess"
    KafkaServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/KafkaServiceRolePolicy"
    AmazonPollyFullAccess = "arn:aws:iam::aws:policy/AmazonPollyFullAccess"
    AmazonSSMMaintenanceWindowRole = "arn:aws:iam::aws:policy/service-role/AmazonSSMMaintenanceWindowRole"
    AmazonRDSEnhancedMonitoringRole = "arn:aws:iam::aws:policy/service-role/AmazonRDSEnhancedMonitoringRole"
    AmazonLexFullAccess = "arn:aws:iam::aws:policy/AmazonLexFullAccess"
    AWSLambdaVPCAccessExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaVPCAccessExecutionRole"
    AmazonMacieServiceRole = "arn:aws:iam::aws:policy/service-role/AmazonMacieServiceRole"
    AmazonLexRunBotsOnly = "arn:aws:iam::aws:policy/AmazonLexRunBotsOnly"
    AWSCertificateManagerPrivateCAAuditor = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAAuditor"
    AmazonSNSFullAccess = "arn:aws:iam::aws:policy/AmazonSNSFullAccess"
    AmazonEKS_CNI_Policy = "arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"
    AWSServiceCatalogAdminFullAccess = "arn:aws:iam::aws:policy/AWSServiceCatalogAdminFullAccess"
    AWSShieldDRTAccessPolicy = "arn:aws:iam::aws:policy/service-role/AWSShieldDRTAccessPolicy"
    CloudSearchReadOnlyAccess = "arn:aws:iam::aws:policy/CloudSearchReadOnlyAccess"
    AWSGreengrassFullAccess = "arn:aws:iam::aws:policy/AWSGreengrassFullAccess"
    NeptuneConsoleFullAccess = "arn:aws:iam::aws:policy/NeptuneConsoleFullAccess"
    AWSCloudFormationReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCloudFormationReadOnlyAccess"
    AmazonRoute53FullAccess = "arn:aws:iam::aws:policy/AmazonRoute53FullAccess"
    AWSLambdaRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaRole"
    AWSLambdaENIManagementAccess = "arn:aws:iam::aws:policy/service-role/AWSLambdaENIManagementAccess"
    AWSOpsWorksCloudWatchLogs = "arn:aws:iam::aws:policy/AWSOpsWorksCloudWatchLogs"
    AmazonAppStreamReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonAppStreamReadOnlyAccess"
    AWSStepFunctionsFullAccess = "arn:aws:iam::aws:policy/AWSStepFunctionsFullAccess"
    CloudTrailServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CloudTrailServiceRolePolicy"
    AmazonInspectorReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonInspectorReadOnlyAccess"
    AWSOrganizationsReadOnlyAccess = "arn:aws:iam::aws:policy/AWSOrganizationsReadOnlyAccess"
    TranslateReadOnly = "arn:aws:iam::aws:policy/TranslateReadOnly"
    AWSCertificateManagerFullAccess = "arn:aws:iam::aws:policy/AWSCertificateManagerFullAccess"
    AWSDeepRacerCloudFormationAccessPolicy = "arn:aws:iam::aws:policy/AWSDeepRacerCloudFormationAccessPolicy"
    AWSIoTEventsReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIoTEventsReadOnlyAccess"
    AWSRoboMakerServicePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSRoboMakerServicePolicy"
    PowerUserAccess = "arn:aws:iam::aws:policy/PowerUserAccess"
    AWSApplicationAutoScalingCustomResourcePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoScalingCustomResourcePolicy"
    GlobalAcceleratorReadOnlyAccess = "arn:aws:iam::aws:policy/GlobalAcceleratorReadOnlyAccess"
    AmazonSageMakerFullAccess = "arn:aws:iam::aws:policy/AmazonSageMakerFullAccess"
    WAFLoggingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/WAFLoggingServiceRolePolicy"
    AWSBackupServiceRolePolicyForRestores = "arn:aws:iam::aws:policy/service-role/AWSBackupServiceRolePolicyForRestores"
    AWSElementalMediaStoreFullAccess = "arn:aws:iam::aws:policy/AWSElementalMediaStoreFullAccess"
    CloudWatchEventsFullAccess = "arn:aws:iam::aws:policy/CloudWatchEventsFullAccess"
    AWSLicenseManagerMemberAccountRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerMemberAccountRolePolicy"
    AWSOrganizationsFullAccess = "arn:aws:iam::aws:policy/AWSOrganizationsFullAccess"
    AWSCodePipeline_FullAccess = "arn:aws:iam::aws:policy/AWSCodePipeline_FullAccess"
    DynamoDBKinesisReplicationServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/DynamoDBKinesisReplicationServiceRolePolicy"
    AWSApplicationAutoscalingElastiCacheRGPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingElastiCacheRGPolicy"
    AmazonAugmentedAIIntegratedAPIAccess = "arn:aws:iam::aws:policy/AmazonAugmentedAIIntegratedAPIAccess"
    AWSElasticDisasterRecoveryReadOnlyAccess = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryReadOnlyAccess"
    AmazonFraudDetectorFullAccessPolicy = "arn:aws:iam::aws:policy/AmazonFraudDetectorFullAccessPolicy"
    AmazonLaunchWizard_Fullaccess = "arn:aws:iam::aws:policy/AmazonLaunchWizard_Fullaccess"
    AmazonChimeSDK = "arn:aws:iam::aws:policy/AmazonChimeSDK"
    AwsGlueDataBrewFullAccessPolicy = "arn:aws:iam::aws:policy/AwsGlueDataBrewFullAccessPolicy"
    AmazonElasticContainerRegistryPublicReadOnly = "arn:aws:iam::aws:policy/AmazonElasticContainerRegistryPublicReadOnly"
    AWSIoTDeviceTesterForFreeRTOSFullAccess = "arn:aws:iam::aws:policy/AWSIoTDeviceTesterForFreeRTOSFullAccess"
    Route53ResolverServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/Route53ResolverServiceRolePolicy"
    WAFV2LoggingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/WAFV2LoggingServiceRolePolicy"
    AWSBudgetsActionsWithAWSResourceControlAccess = "arn:aws:iam::aws:policy/AWSBudgetsActionsWithAWSResourceControlAccess"
    AWSElasticBeanstalkManagedUpdatesCustomerRolePolicy = "arn:aws:iam::aws:policy/AWSElasticBeanstalkManagedUpdatesCustomerRolePolicy"
    AdministratorAccess_Amplify = "arn:aws:iam::aws:policy/AdministratorAccess-Amplify"
    AmazonRoute53RecoveryReadinessFullAccess = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryReadinessFullAccess"
    AWSNetworkManagerFullAccess = "arn:aws:iam::aws:policy/AWSNetworkManagerFullAccess"
    AmazonSageMakerServiceCatalogProductsEventsServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsEventsServiceRolePolicy"
    AWSMarketplaceAmiIngestion = "arn:aws:iam::aws:policy/AWSMarketplaceAmiIngestion"
    AWSPrivateMarketplaceRequests = "arn:aws:iam::aws:policy/AWSPrivateMarketplaceRequests"
    CloudWatchApplicationInsightsReadOnlyAccess = "arn:aws:iam::aws:policy/CloudWatchApplicationInsightsReadOnlyAccess"
    AdministratorAccess_AWSElasticBeanstalk = "arn:aws:iam::aws:policy/AdministratorAccess-AWSElasticBeanstalk"
    AmazonSageMakerMechanicalTurkAccess = "arn:aws:iam::aws:policy/AmazonSageMakerMechanicalTurkAccess"
    AmazonTimestreamConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonTimestreamConsoleFullAccess"
    AWSWAFConsoleFullAccess = "arn:aws:iam::aws:policy/AWSWAFConsoleFullAccess"
    AWSGlueSchemaRegistryReadonlyAccess = "arn:aws:iam::aws:policy/AWSGlueSchemaRegistryReadonlyAccess"
    AWSNetworkManagerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSNetworkManagerServiceRolePolicy"
    AWSAppMeshServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSAppMeshServiceRolePolicy"
    AWSConfigRemediationServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSConfigRemediationServiceRolePolicy"
    ConfigConformsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ConfigConformsServiceRolePolicy"
    AmazonEventBridgeReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonEventBridgeReadOnlyAccess"
    AWSCodeStarNotificationsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSCodeStarNotificationsServiceRolePolicy"
    AWSMarketplacePurchaseOrdersServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSMarketplacePurchaseOrdersServiceRolePolicy"
    AWSElementalMediaTailorReadOnly = "arn:aws:iam::aws:policy/AWSElementalMediaTailorReadOnly"
    AmazonInspector2ServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonInspector2ServiceRolePolicy"
    AmazonKendraFullAccess = "arn:aws:iam::aws:policy/AmazonKendraFullAccess"
    AmazonEMRFullAccessPolicy_v2 = "arn:aws:iam::aws:policy/AmazonEMRFullAccessPolicy_v2"
    AmazonS3OutpostsFullAccess = "arn:aws:iam::aws:policy/AmazonS3OutpostsFullAccess"
    AppRunnerNetworkingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AppRunnerNetworkingServiceRolePolicy"
    AmazonRedshiftQueryEditorV2FullAccess = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2FullAccess"
    AmazonSageMakerServiceCatalogProductsCloudformationServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsCloudformationServiceRolePolicy"
    AWSQuickSightElasticsearchPolicy = "arn:aws:iam::aws:policy/service-role/AWSQuickSightElasticsearchPolicy"
    AmazonRoute53RecoveryControlConfigFullAccess = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryControlConfigFullAccess"
    AWSApplicationAutoscalingCassandraTablePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingCassandraTablePolicy"
    AWSSystemsManagerAccountDiscoveryServicePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSystemsManagerAccountDiscoveryServicePolicy"
    AWSPanoramaServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSPanoramaServiceLinkedRolePolicy"
    AmazonDevOpsGuruFullAccess = "arn:aws:iam::aws:policy/AmazonDevOpsGuruFullAccess"
    AWSResourceAccessManagerReadOnlyAccess = "arn:aws:iam::aws:policy/AWSResourceAccessManagerReadOnlyAccess"
    AmazonEventBridgeFullAccess = "arn:aws:iam::aws:policy/AmazonEventBridgeFullAccess"
    AWSThinkboxAWSPortalAdminPolicy = "arn:aws:iam::aws:policy/AWSThinkboxAWSPortalAdminPolicy"
    AWSElasticBeanstalkReadOnly = "arn:aws:iam::aws:policy/AWSElasticBeanstalkReadOnly"
    EC2InstanceProfileForImageBuilderECRContainerBuilds = "arn:aws:iam::aws:policy/EC2InstanceProfileForImageBuilderECRContainerBuilds"
    AWSCodeDeployRoleForLambdaLimited = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRoleForLambdaLimited"
    AWSAuditManagerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSAuditManagerServiceRolePolicy"
    AWSBackupAuditAccess = "arn:aws:iam::aws:policy/AWSBackupAuditAccess"
    CloudWatchSyntheticsReadOnlyAccess = "arn:aws:iam::aws:policy/CloudWatchSyntheticsReadOnlyAccess"
    AmazonNimbleStudio_StudioUser = "arn:aws:iam::aws:policy/AmazonNimbleStudio-StudioUser"
    AWSCloudTrail_FullAccess = "arn:aws:iam::aws:policy/AWSCloudTrail_FullAccess"
    AccessAnalyzerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AccessAnalyzerServiceRolePolicy"
    AmazonRoute53ResolverReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53ResolverReadOnlyAccess"
    AmazonBraketJobsExecutionPolicy = "arn:aws:iam::aws:policy/AmazonBraketJobsExecutionPolicy"
    AmazonEC2RolePolicyForLaunchWizard = "arn:aws:iam::aws:policy/AmazonEC2RolePolicyForLaunchWizard"
    AmazonAppFlowReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonAppFlowReadOnlyAccess"
    AmazonLookoutVisionConsoleReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonLookoutVisionConsoleReadOnlyAccess"
    AWSQuickSightTimestreamPolicy = "arn:aws:iam::aws:policy/service-role/AWSQuickSightTimestreamPolicy"
    AmazonManagedBlockchainFullAccess = "arn:aws:iam::aws:policy/AmazonManagedBlockchainFullAccess"
    ServiceQuotasFullAccess = "arn:aws:iam::aws:policy/ServiceQuotasFullAccess"
    AmazonTimestreamFullAccess = "arn:aws:iam::aws:policy/AmazonTimestreamFullAccess"
    AWSBackupServiceRolePolicyForS3Backup = "arn:aws:iam::aws:policy/AWSBackupServiceRolePolicyForS3Backup"
    AWSAppRunnerFullAccess = "arn:aws:iam::aws:policy/AWSAppRunnerFullAccess"
    AmazonInspector2FullAccess = "arn:aws:iam::aws:policy/AmazonInspector2FullAccess"
    AmazonSageMakerServiceCatalogProductsCodePipelineServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsCodePipelineServiceRolePolicy"
    ElementalAppliancesSoftwareReadOnlyAccess = "arn:aws:iam::aws:policy/ElementalAppliancesSoftwareReadOnlyAccess"
    AmazonLookoutVisionFullAccess = "arn:aws:iam::aws:policy/AmazonLookoutVisionFullAccess"
    AWSCodeDeployRoleForCloudFormation = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRoleForCloudFormation"
    BatchServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/BatchServiceRolePolicy"
    AmazonHoneycodeServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonHoneycodeServiceRolePolicy"
    AWSBugBustPlayerAccess = "arn:aws:iam::aws:policy/AWSBugBustPlayerAccess"
    AmazonSageMakerEdgeDeviceFleetPolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerEdgeDeviceFleetPolicy"
    AWSIoTSiteWiseMonitorServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSIoTSiteWiseMonitorServiceRolePolicy"
    AmazonHoneycodeReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonHoneycodeReadOnlyAccess"
    AWSCloudFormationFullAccess = "arn:aws:iam::aws:policy/AWSCloudFormationFullAccess"
    AWSPanoramaApplianceRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSPanoramaApplianceRolePolicy"
    AmazonLookoutMetricsFullAccess = "arn:aws:iam::aws:policy/AmazonLookoutMetricsFullAccess"
    AWSApplicationMigrationAgentPolicy = "arn:aws:iam::aws:policy/AWSApplicationMigrationAgentPolicy"
    AWSOpsWorks_FullAccess = "arn:aws:iam::aws:policy/AWSOpsWorks_FullAccess"
    AmazonRDSCustomPreviewServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSCustomPreviewServiceRolePolicy"
    AmazonRoute53RecoveryControlConfigReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryControlConfigReadOnlyAccess"
    AmazonChimeTranscriptionServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeTranscriptionServiceLinkedRolePolicy"
    AWSNetworkFirewallServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSNetworkFirewallServiceRolePolicy"
    ElementalAppliancesSoftwareFullAccess = "arn:aws:iam::aws:policy/ElementalAppliancesSoftwareFullAccess"
    AmazonMachineLearningRoleforRedshiftDataSourceV3 = "arn:aws:iam::aws:policy/service-role/AmazonMachineLearningRoleforRedshiftDataSourceV3"
    AmazonAugmentedAIHumanLoopFullAccess = "arn:aws:iam::aws:policy/AmazonAugmentedAIHumanLoopFullAccess"
    AmazonLookoutEquipmentReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonLookoutEquipmentReadOnlyAccess"
    AmazonSageMakerServiceCatalogProductsGlueServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsGlueServiceRolePolicy"
    AmazonCloudWatchRUMFullAccess = "arn:aws:iam::aws:policy/AmazonCloudWatchRUMFullAccess"
    AWSDataExchangeReadOnly = "arn:aws:iam::aws:policy/AWSDataExchangeReadOnly"
    AWSMarketplaceSellerProductsFullAccess = "arn:aws:iam::aws:policy/AWSMarketplaceSellerProductsFullAccess"
    AWSMarketplaceLicenseManagementServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSMarketplaceLicenseManagementServiceRolePolicy"
    AWSProtonReadOnlyAccess = "arn:aws:iam::aws:policy/AWSProtonReadOnlyAccess"
    AmazonLexV2BotPolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonLexV2BotPolicy"
    AWSIQContractServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSIQContractServiceRolePolicy"
    AWSStorageGatewayServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSStorageGatewayServiceRolePolicy"
    AWSBackupOrganizationAdminAccess = "arn:aws:iam::aws:policy/AWSBackupOrganizationAdminAccess"
    AWSIoTSiteWiseMonitorPortalAccess = "arn:aws:iam::aws:policy/service-role/AWSIoTSiteWiseMonitorPortalAccess"
    AWSIdentitySyncReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIdentitySyncReadOnlyAccess"
    AWSAuditManagerAdministratorAccess = "arn:aws:iam::aws:policy/AWSAuditManagerAdministratorAccess"
    ElementalSupportCenterFullAccess = "arn:aws:iam::aws:policy/ElementalSupportCenterFullAccess"
    AmazonHoneycodeFullAccess = "arn:aws:iam::aws:policy/AmazonHoneycodeFullAccess"
    AmazonWorkDocsReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonWorkDocsReadOnlyAccess"
    CloudWatchLambdaInsightsExecutionRolePolicy = "arn:aws:iam::aws:policy/CloudWatchLambdaInsightsExecutionRolePolicy"
    AmazonConnectVoiceIDFullAccess = "arn:aws:iam::aws:policy/AmazonConnectVoiceIDFullAccess"
    AWSGlobalAcceleratorSLRPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSGlobalAcceleratorSLRPolicy"
    EC2InstanceProfileForImageBuilder = "arn:aws:iam::aws:policy/EC2InstanceProfileForImageBuilder"
    AWSServiceRoleForLogDeliveryPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForLogDeliveryPolicy"
    AmazonCodeGuruReviewerFullAccess = "arn:aws:iam::aws:policy/AmazonCodeGuruReviewerFullAccess"
    AWSVPCS2SVpnServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSVPCS2SVpnServiceRolePolicy"
    AWSImageBuilderFullAccess = "arn:aws:iam::aws:policy/AWSImageBuilderFullAccess"
    AWSIncidentManagerResolverAccess = "arn:aws:iam::aws:policy/AWSIncidentManagerResolverAccess"
    AWSCertificateManagerPrivateCAPrivilegedUser = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAPrivilegedUser"
    AmazonCloudWatchEvidentlyReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonCloudWatchEvidentlyReadOnlyAccess"
    AWSIdentitySyncFullAccess = "arn:aws:iam::aws:policy/AWSIdentitySyncFullAccess"
    AmazonSageMakerServiceCatalogProductsFirehoseServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsFirehoseServiceRolePolicy"
    AmazonSSMPatchAssociation = "arn:aws:iam::aws:policy/AmazonSSMPatchAssociation"
    AWSBudgetsReadOnlyAccess = "arn:aws:iam::aws:policy/AWSBudgetsReadOnlyAccess"
    AWSOpsWorksRegisterCLI_OnPremises = "arn:aws:iam::aws:policy/AWSOpsWorksRegisterCLI_OnPremises"
    Health_OrganizationsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/Health_OrganizationsServiceRolePolicy"
    AWSMigrationHubStrategyServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSMigrationHubStrategyServiceRolePolicy"
    AWSApplicationMigrationVCenterClientPolicy = "arn:aws:iam::aws:policy/AWSApplicationMigrationVCenterClientPolicy"
    AmazonRDSCustomServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSCustomServiceRolePolicy"
    AmazonElasticContainerRegistryPublicFullAccess = "arn:aws:iam::aws:policy/AmazonElasticContainerRegistryPublicFullAccess"
    AmazonMCSReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMCSReadOnlyAccess"
    AmazonOpenSearchServiceFullAccess = "arn:aws:iam::aws:policy/AmazonOpenSearchServiceFullAccess"
    AWSRoboMaker_FullAccess = "arn:aws:iam::aws:policy/AWSRoboMaker_FullAccess"
    AWSAppMeshPreviewServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSAppMeshPreviewServiceRolePolicy"
    ServiceQuotasServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ServiceQuotasServiceRolePolicy"
    AWSLambdaMSKExecutionRole = "arn:aws:iam::aws:policy/service-role/AWSLambdaMSKExecutionRole"
    ComputeOptimizerReadOnlyAccess = "arn:aws:iam::aws:policy/ComputeOptimizerReadOnlyAccess"
    AlexaForBusinessPolyDelegatedAccessPolicy = "arn:aws:iam::aws:policy/AlexaForBusinessPolyDelegatedAccessPolicy"
    AWSMarketplaceProcurementSystemAdminFullAccess = "arn:aws:iam::aws:policy/AWSMarketplaceProcurementSystemAdminFullAccess"
    AWSAccountManagementReadOnlyAccess = "arn:aws:iam::aws:policy/AWSAccountManagementReadOnlyAccess"
    AmazonEKSFargatePodExecutionRolePolicy = "arn:aws:iam::aws:policy/AmazonEKSFargatePodExecutionRolePolicy"
    AWSIoTWirelessReadOnlyAccess = "arn:aws:iam::aws:policy/AWSIoTWirelessReadOnlyAccess"
    AmazonSageMakerPipelinesIntegrations = "arn:aws:iam::aws:policy/AmazonSageMakerPipelinesIntegrations"
    AppRunnerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AppRunnerServiceRolePolicy"
    AWSThinkboxDeadlineResourceTrackerAdminPolicy = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineResourceTrackerAdminPolicy"
    AmazonRedshiftAllCommandsFullAccess = "arn:aws:iam::aws:policy/AmazonRedshiftAllCommandsFullAccess"
    IAMAccessAdvisorReadOnly = "arn:aws:iam::aws:policy/IAMAccessAdvisorReadOnly"
    AmazonSageMakerFeatureStoreAccess = "arn:aws:iam::aws:policy/AmazonSageMakerFeatureStoreAccess"
    AmazonCodeGuruReviewerReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonCodeGuruReviewerReadOnlyAccess"
    AWSThinkboxAWSPortalGatewayPolicy = "arn:aws:iam::aws:policy/AWSThinkboxAWSPortalGatewayPolicy"
    AWSElasticDisasterRecoveryFailbackPolicy = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryFailbackPolicy"
    AWSApplicationAutoscalingKafkaClusterPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingKafkaClusterPolicy"
    AWSSystemsManagerOpsDataSyncServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSystemsManagerOpsDataSyncServiceRolePolicy"
    AmazonCodeGuruProfilerFullAccess = "arn:aws:iam::aws:policy/AmazonCodeGuruProfilerFullAccess"
    AWSProtonDeveloperAccess = "arn:aws:iam::aws:policy/AWSProtonDeveloperAccess"
    AmazonElasticFileSystemServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonElasticFileSystemServiceRolePolicy"
    AmazonSageMakerGroundTruthExecution = "arn:aws:iam::aws:policy/AmazonSageMakerGroundTruthExecution"
    AWSResourceAccessManagerFullAccess = "arn:aws:iam::aws:policy/AWSResourceAccessManagerFullAccess"
    CertificateManagerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CertificateManagerServiceRolePolicy"
    AWSIoTDeviceDefenderEnableIoTLoggingMitigationAction = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderEnableIoTLoggingMitigationAction"
    AWSGrafanaWorkspacePermissionManagement = "arn:aws:iam::aws:policy/AWSGrafanaWorkspacePermissionManagement"
    AmazonNimbleStudio_LaunchProfileWorker = "arn:aws:iam::aws:policy/AmazonNimbleStudio-LaunchProfileWorker"
    AWSElasticBeanstalkRoleCWL = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleCWL"
    DynamoDBCloudWatchContributorInsightsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/DynamoDBCloudWatchContributorInsightsServiceRolePolicy"
    AmazonDetectiveServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonDetectiveServiceLinkedRolePolicy"
    AWSElasticBeanstalkRoleRDS = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleRDS"
    AmazonRedshiftQueryEditorV2ReadSharing = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2ReadSharing"
    AWSECRPullThroughCache_ServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSECRPullThroughCache_ServiceRolePolicy"
    AWSPanoramaServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSPanoramaServiceRolePolicy"
    AWSElasticDisasterRecoveryConversionServerPolicy = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryConversionServerPolicy"
    AmazonEMRReadOnlyAccessPolicy_v2 = "arn:aws:iam::aws:policy/AmazonEMRReadOnlyAccessPolicy_v2"
    AmazonEventBridgeApiDestinationsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEventBridgeApiDestinationsServiceRolePolicy"
    AWSServiceRoleForCodeGuru_Profiler = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForCodeGuru-Profiler"
    AmazonChimeVoiceConnectorServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeVoiceConnectorServiceLinkedRolePolicy"
    AmazonPrometheusQueryAccess = "arn:aws:iam::aws:policy/AmazonPrometheusQueryAccess"
    AmazonGrafanaRedshiftAccess = "arn:aws:iam::aws:policy/service-role/AmazonGrafanaRedshiftAccess"
    AmazonDevOpsGuruConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonDevOpsGuruConsoleFullAccess"
    AmazonWorkDocsFullAccess = "arn:aws:iam::aws:policy/AmazonWorkDocsFullAccess"
    AmazonHoneycodeWorkbookReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonHoneycodeWorkbookReadOnlyAccess"
    MediaPackageServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/MediaPackageServiceRolePolicy"
    AmazonGrafanaAthenaAccess = "arn:aws:iam::aws:policy/service-role/AmazonGrafanaAthenaAccess"
    IAMAccessAnalyzerReadOnlyAccess = "arn:aws:iam::aws:policy/IAMAccessAnalyzerReadOnlyAccess"
    AmazonCloudWatchRUMServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonCloudWatchRUMServiceRolePolicy"
    AmazonEventBridgeSchemasServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEventBridgeSchemasServiceRolePolicy"
    AWSIoTDeviceDefenderPublishFindingsToSNSMitigationAction = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderPublishFindingsToSNSMitigationAction"
    AmazonQLDBConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonQLDBConsoleFullAccess"
    AWSGlueSchemaRegistryFullAccess = "arn:aws:iam::aws:policy/AWSGlueSchemaRegistryFullAccess"
    AmazonEKSConnectorServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSConnectorServiceRolePolicy"
    AWSServiceCatalogAppRegistryServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceCatalogAppRegistryServiceRolePolicy"
    AWSIoTFleetHubFederationAccess = "arn:aws:iam::aws:policy/service-role/AWSIoTFleetHubFederationAccess"
    AWSProtonSyncServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSProtonSyncServiceRolePolicy"
    AmazonElasticFileSystemClientReadWriteAccess = "arn:aws:iam::aws:policy/AmazonElasticFileSystemClientReadWriteAccess"
    AWSElasticDisasterRecoveryServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticDisasterRecoveryServiceRolePolicy"
    AWSApplicationAutoscalingComprehendEndpointPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingComprehendEndpointPolicy"
    AWSCloudShellFullAccess = "arn:aws:iam::aws:policy/AWSCloudShellFullAccess"
    AWSIoTDeviceDefenderAddThingsToThingGroupMitigationAction = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderAddThingsToThingGroupMitigationAction"
    AmazonMemoryDBReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMemoryDBReadOnlyAccess"
    AWSIoTWirelessDataAccess = "arn:aws:iam::aws:policy/AWSIoTWirelessDataAccess"
    AmazonQLDBFullAccess = "arn:aws:iam::aws:policy/AmazonQLDBFullAccess"
    AmazonWorkSpacesWebReadOnly = "arn:aws:iam::aws:policy/AmazonWorkSpacesWebReadOnly"
    AmazonAugmentedAIFullAccess = "arn:aws:iam::aws:policy/AmazonAugmentedAIFullAccess"
    AWSDeepRacerAccountAdminAccess = "arn:aws:iam::aws:policy/AWSDeepRacerAccountAdminAccess"
    AWSEC2CapacityReservationFleetRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2CapacityReservationFleetRolePolicy"
    AmazonKeyspacesFullAccess = "arn:aws:iam::aws:policy/AmazonKeyspacesFullAccess"
    AWSIoTDeviceDefenderReplaceDefaultPolicyMitigationAction = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderReplaceDefaultPolicyMitigationAction"
    AWSAppMeshReadOnly = "arn:aws:iam::aws:policy/AWSAppMeshReadOnly"
    ComputeOptimizerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ComputeOptimizerServiceRolePolicy"
    AWSApplicationMigrationFullAccess = "arn:aws:iam::aws:policy/AWSApplicationMigrationFullAccess"
    AWSLakeFormationCrossAccountManager = "arn:aws:iam::aws:policy/AWSLakeFormationCrossAccountManager"
    AWSGlueDataBrewServiceRole = "arn:aws:iam::aws:policy/service-role/AWSGlueDataBrewServiceRole"
    AmazonBraketFullAccess = "arn:aws:iam::aws:policy/AmazonBraketFullAccess"
    AWSElasticBeanstalkManagedUpdatesServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticBeanstalkManagedUpdatesServiceRolePolicy"
    AmazonLexChannelsAccess = "arn:aws:iam::aws:policy/aws-service-role/AmazonLexChannelsAccess"
    AlexaForBusinessLifesizeDelegatedAccessPolicy = "arn:aws:iam::aws:policy/AlexaForBusinessLifesizeDelegatedAccessPolicy"
    AmazonOpenSearchServiceCognitoAccess = "arn:aws:iam::aws:policy/AmazonOpenSearchServiceCognitoAccess"
    AmazonTimestreamReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonTimestreamReadOnlyAccess"
    AWSPanoramaFullAccess = "arn:aws:iam::aws:policy/AWSPanoramaFullAccess"
    AmazonInspector2ReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonInspector2ReadOnlyAccess"
    AmazonQLDBReadOnly = "arn:aws:iam::aws:policy/AmazonQLDBReadOnly"
    AWSChatbotServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSChatbotServiceLinkedRolePolicy"
    AWSDeepRacerDefaultMultiUserAccess = "arn:aws:iam::aws:policy/AWSDeepRacerDefaultMultiUserAccess"
    AWSLambda_ReadOnlyAccess = "arn:aws:iam::aws:policy/AWSLambda_ReadOnlyAccess"
    AWSCodePipeline_ReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCodePipeline_ReadOnlyAccess"
    AWSPrivateNetworksServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSPrivateNetworksServiceRolePolicy"
    S3StorageLensServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/S3StorageLensServiceRolePolicy"
    ServerMigrationServiceConsoleFullAccess = "arn:aws:iam::aws:policy/ServerMigrationServiceConsoleFullAccess"
    AWSAppSyncServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSAppSyncServiceRolePolicy"
    AmazonSageMakerServiceCatalogProductsCodeBuildServiceRolePolicy = "arn:aws:iam::aws:policy/AmazonSageMakerServiceCatalogProductsCodeBuildServiceRolePolicy"
    AWSAppMeshFullAccess = "arn:aws:iam::aws:policy/AWSAppMeshFullAccess"
    AWSIncidentManagerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSIncidentManagerServiceRolePolicy"
    AWSProtonFullAccess = "arn:aws:iam::aws:policy/AWSProtonFullAccess"
    AWSElasticDisasterRecoveryAgentPolicy = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryAgentPolicy"
    AWSCloud9SSMInstanceProfile = "arn:aws:iam::aws:policy/AWSCloud9SSMInstanceProfile"
    ElementalActivationsDownloadSoftwareAccess = "arn:aws:iam::aws:policy/ElementalActivationsDownloadSoftwareAccess"
    AWSPanoramaGreengrassGroupRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSPanoramaGreengrassGroupRolePolicy"
    AmazonDetectiveFullAccess = "arn:aws:iam::aws:policy/AmazonDetectiveFullAccess"
    AWSSSMOpsInsightsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSSMOpsInsightsServiceRolePolicy"
    AWSTransferReadOnlyAccess = "arn:aws:iam::aws:policy/AWSTransferReadOnlyAccess"
    ServiceQuotasReadOnlyAccess = "arn:aws:iam::aws:policy/ServiceQuotasReadOnlyAccess"
    EC2FleetTimeShiftableServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/EC2FleetTimeShiftableServiceRolePolicy"
    MigrationHubDMSAccessServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/MigrationHubDMSAccessServiceRolePolicy"
    AWSServiceCatalogEndUserReadOnlyAccess = "arn:aws:iam::aws:policy/AWSServiceCatalogEndUserReadOnlyAccess"
    AWSIotRoboRunnerFullAccess = "arn:aws:iam::aws:policy/AWSIotRoboRunnerFullAccess"
    ElementalActivationsFullAccess = "arn:aws:iam::aws:policy/ElementalActivationsFullAccess"
    AWSIQPermissionServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSIQPermissionServiceRolePolicy"
    Route53RecoveryReadinessServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/Route53RecoveryReadinessServiceRolePolicy"
    AmazonEKSForFargateServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSForFargateServiceRolePolicy"
    ElementalActivationsReadOnlyAccess = "arn:aws:iam::aws:policy/ElementalActivationsReadOnlyAccess"
    MigrationHubSMSAccessServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/MigrationHubSMSAccessServiceRolePolicy"
    CloudFormationStackSetsOrgAdminServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CloudFormationStackSetsOrgAdminServiceRolePolicy"
    AWSIPAMServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSIPAMServiceRolePolicy"
    AmazonEventBridgeSchemasFullAccess = "arn:aws:iam::aws:policy/AmazonEventBridgeSchemasFullAccess"
    AWSMarketplaceSellerFullAccess = "arn:aws:iam::aws:policy/AWSMarketplaceSellerFullAccess"
    AmazonRedshiftQueryEditorV2NoSharing = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2NoSharing"
    CloudWatchAutomaticDashboardsAccess = "arn:aws:iam::aws:policy/CloudWatchAutomaticDashboardsAccess"
    AWSDeepRacerFullAccess = "arn:aws:iam::aws:policy/AWSDeepRacerFullAccess"
    AmazonWorkMailEventsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonWorkMailEventsServiceRolePolicy"
    AmazonHoneycodeTeamAssociationFullAccess = "arn:aws:iam::aws:policy/AmazonHoneycodeTeamAssociationFullAccess"
    AmazonPrometheusRemoteWriteAccess = "arn:aws:iam::aws:policy/AmazonPrometheusRemoteWriteAccess"
    AmazonDevOpsGuruReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonDevOpsGuruReadOnlyAccess"
    AmazonEventBridgeSchemasReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonEventBridgeSchemasReadOnlyAccess"
    AmazonFISServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonFISServiceRolePolicy"
    AWSThinkboxDeadlineSpotEventPluginWorkerPolicy = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineSpotEventPluginWorkerPolicy"
    AWSCloudWatchAlarms_ActionSSMIncidentsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSCloudWatchAlarms_ActionSSMIncidentsServiceRolePolicy"
    AWSIoTWirelessFullPublishAccess = "arn:aws:iam::aws:policy/AWSIoTWirelessFullPublishAccess"
    GameLiftGameServerGroupPolicy = "arn:aws:iam::aws:policy/GameLiftGameServerGroupPolicy"
    AmazonMWAAServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonMWAAServiceRolePolicy"
    AmazonWorkSpacesWebServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonWorkSpacesWebServiceRolePolicy"
    AWSQuicksightOpenSearchPolicy = "arn:aws:iam::aws:policy/service-role/AWSQuicksightOpenSearchPolicy"
    AWSElasticDisasterRecoveryFailbackInstallationPolicy = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryFailbackInstallationPolicy"
    AmazonConnect_FullAccess = "arn:aws:iam::aws:policy/AmazonConnect_FullAccess"
    AWSElementalMediaLiveFullAccess = "arn:aws:iam::aws:policy/AWSElementalMediaLiveFullAccess"
    AWSMarketplaceSellerProductsReadOnly = "arn:aws:iam::aws:policy/AWSMarketplaceSellerProductsReadOnly"
    AmazonMCSFullAccess = "arn:aws:iam::aws:policy/AmazonMCSFullAccess"
    AWSIoTSiteWiseConsoleFullAccess = "arn:aws:iam::aws:policy/AWSIoTSiteWiseConsoleFullAccess"
    AmazonElasticFileSystemClientFullAccess = "arn:aws:iam::aws:policy/AmazonElasticFileSystemClientFullAccess"
    AWSIoTDeviceDefenderUpdateDeviceCertMitigationAction = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderUpdateDeviceCertMitigationAction"
    AWSThinkboxAssetServerPolicy = "arn:aws:iam::aws:policy/AWSThinkboxAssetServerPolicy"
    AWSForWordPressPluginPolicy = "arn:aws:iam::aws:policy/AWSForWordPressPluginPolicy"
    KafkaConnectServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/KafkaConnectServiceRolePolicy"
    AWSTransferFullAccess = "arn:aws:iam::aws:policy/AWSTransferFullAccess"
    AWSServiceRoleForAmazonEKSNodegroup = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForAmazonEKSNodegroup"
    AWSGrafanaAccountAdministrator = "arn:aws:iam::aws:policy/AWSGrafanaAccountAdministrator"
    AWSBackupOperatorAccess = "arn:aws:iam::aws:policy/AWSBackupOperatorAccess"
    AWSMigrationHubRefactorSpacesServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSMigrationHubRefactorSpacesServiceRolePolicy"
    AWSApplicationAutoscalingLambdaConcurrencyPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingLambdaConcurrencyPolicy"
    AWSBudgetsActionsRolePolicyForResourceAdministrationWithSSM = "arn:aws:iam::aws:policy/AWSBudgetsActionsRolePolicyForResourceAdministrationWithSSM"
    AWSIoTDeviceDefenderUpdateCACertMitigationAction = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderUpdateCACertMitigationAction"
    AWSBackupServiceLinkedRolePolicyForBackupTest = "arn:aws:iam::aws:policy/aws-service-role/AWSBackupServiceLinkedRolePolicyForBackupTest"
    AWSApplicationMigrationMGHAccess = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationMGHAccess"
    AWSDeviceFarmTestGridServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSDeviceFarmTestGridServiceRolePolicy"
    AWSBackupServiceRolePolicyForS3Restore = "arn:aws:iam::aws:policy/AWSBackupServiceRolePolicyForS3Restore"
    AmazonLookoutEquipmentFullAccess = "arn:aws:iam::aws:policy/AmazonLookoutEquipmentFullAccess"
    AWSPurchaseOrdersServiceRolePolicy = "arn:aws:iam::aws:policy/AWSPurchaseOrdersServiceRolePolicy"
    AmazonHoneycodeTeamAssociationReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonHoneycodeTeamAssociationReadOnlyAccess"
    AmazonWorkSpacesServiceAccess = "arn:aws:iam::aws:policy/AmazonWorkSpacesServiceAccess"
    AWSSecurityHubOrganizationsAccess = "arn:aws:iam::aws:policy/AWSSecurityHubOrganizationsAccess"
    AmazonElasticFileSystemsUtils = "arn:aws:iam::aws:policy/AmazonElasticFileSystemsUtils"
    AWSCostAndUsageReportAutomationPolicy = "arn:aws:iam::aws:policy/service-role/AWSCostAndUsageReportAutomationPolicy"
    MemoryDBServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/MemoryDBServiceRolePolicy"
    AWSLicenseManagerConsumptionPolicy = "arn:aws:iam::aws:policy/service-role/AWSLicenseManagerConsumptionPolicy"
    AWSTransferConsoleFullAccess = "arn:aws:iam::aws:policy/AWSTransferConsoleFullAccess"
    AmazonEKSServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSServiceRolePolicy"
    AWSIoTWirelessLogging = "arn:aws:iam::aws:policy/AWSIoTWirelessLogging"
    AWSConfigMultiAccountSetupPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSConfigMultiAccountSetupPolicy"
    AWSIoTWirelessFullAccess = "arn:aws:iam::aws:policy/AWSIoTWirelessFullAccess"
    AWSElementalMediaLiveReadOnly = "arn:aws:iam::aws:policy/AWSElementalMediaLiveReadOnly"
    AmazonElasticFileSystemClientReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonElasticFileSystemClientReadOnlyAccess"
    AmazonElasticMapReducePlacementGroupPolicy = "arn:aws:iam::aws:policy/AmazonElasticMapReducePlacementGroupPolicy"
    AWSElasticDisasterRecoveryConsoleFullAccess = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryConsoleFullAccess"
    AmazonCognitoIdpServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonCognitoIdpServiceRolePolicy"
    AmazonMQServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonMQServiceRolePolicy"
    AWSApplicationMigrationServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationMigrationServiceRolePolicy"
    AmazonMemoryDBFullAccess = "arn:aws:iam::aws:policy/AmazonMemoryDBFullAccess"
    AmazonKeyspacesReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonKeyspacesReadOnlyAccess"
    AWSElasticDisasterRecoveryAgentInstallationPolicy = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryAgentInstallationPolicy"
    AWSMigrationHubStrategyCollector = "arn:aws:iam::aws:policy/AWSMigrationHubStrategyCollector"
    CloudFormationStackSetsOrgMemberServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/CloudFormationStackSetsOrgMemberServiceRolePolicy"
    AWSResourceAccessManagerResourceShareParticipantAccess = "arn:aws:iam::aws:policy/AWSResourceAccessManagerResourceShareParticipantAccess"
    AmazonRedshiftQueryEditorV2ReadWriteSharing = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2ReadWriteSharing"
    AWSBillingReadOnlyAccess = "arn:aws:iam::aws:policy/AWSBillingReadOnlyAccess"
    ServerMigrationServiceRoleForInstanceValidation = "arn:aws:iam::aws:policy/service-role/ServerMigrationServiceRoleForInstanceValidation"
    AWSApplicationAutoscalingNeptuneClusterPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingNeptuneClusterPolicy"
    AWSBackupFullAccess = "arn:aws:iam::aws:policy/AWSBackupFullAccess"
    AmazonDevOpsGuruServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonDevOpsGuruServiceRolePolicy"
    AWSElasticBeanstalkRoleWorkerTier = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleWorkerTier"
    AmazonCodeGuruProfilerReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonCodeGuruProfilerReadOnlyAccess"
    ElementalActivationsGenerateLicenses = "arn:aws:iam::aws:policy/ElementalActivationsGenerateLicenses"
    AWSShieldServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSShieldServiceRolePolicy"
    AWSBugBustServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSBugBustServiceRolePolicy"
    AWSAppRunnerServicePolicyForECRAccess = "arn:aws:iam::aws:policy/service-role/AWSAppRunnerServicePolicyForECRAccess"
    AWSNetworkManagerReadOnlyAccess = "arn:aws:iam::aws:policy/AWSNetworkManagerReadOnlyAccess"
    AmazonDevOpsGuruOrganizationsAccess = "arn:aws:iam::aws:policy/AmazonDevOpsGuruOrganizationsAccess"
    AmazonEMRServicePolicy_v2 = "arn:aws:iam::aws:policy/service-role/AmazonEMRServicePolicy_v2"
    AWSApplicationMigrationReadOnlyAccess = "arn:aws:iam::aws:policy/AWSApplicationMigrationReadOnlyAccess"
    AWSServiceCatalogAppRegistryReadOnlyAccess = "arn:aws:iam::aws:policy/AWSServiceCatalogAppRegistryReadOnlyAccess"
    AWSServiceRoleForCloudWatchAlarmsActionSSMServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForCloudWatchAlarmsActionSSMServiceRolePolicy"
    IVSRecordToS3 = "arn:aws:iam::aws:policy/aws-service-role/IVSRecordToS3"
    AmazonRoute53RecoveryReadinessReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryReadinessReadOnlyAccess"
    AmazonWorkMailMessageFlowReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonWorkMailMessageFlowReadOnlyAccess"
    CloudWatchSyntheticsFullAccess = "arn:aws:iam::aws:policy/CloudWatchSyntheticsFullAccess"
    AWSDataExchangeSubscriberFullAccess = "arn:aws:iam::aws:policy/AWSDataExchangeSubscriberFullAccess"
    IAMAccessAnalyzerFullAccess = "arn:aws:iam::aws:policy/IAMAccessAnalyzerFullAccess"
    AWSCodeArtifactAdminAccess = "arn:aws:iam::aws:policy/AWSCodeArtifactAdminAccess"
    AWSServiceCatalogAdminReadOnlyAccess = "arn:aws:iam::aws:policy/AWSServiceCatalogAdminReadOnlyAccess"
    AWSQuickSightSageMakerPolicy = "arn:aws:iam::aws:policy/service-role/AWSQuickSightSageMakerPolicy"
    AWSDataLifecycleManagerServiceRoleForAMIManagement = "arn:aws:iam::aws:policy/service-role/AWSDataLifecycleManagerServiceRoleForAMIManagement"
    AmazonMonitronFullAccess = "arn:aws:iam::aws:policy/AmazonMonitronFullAccess"
    AmazonHealthLakeReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonHealthLakeReadOnlyAccess"
    AmazonWorkSpacesSelfServiceAccess = "arn:aws:iam::aws:policy/AmazonWorkSpacesSelfServiceAccess"
    AmazonManagedBlockchainServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonManagedBlockchainServiceRolePolicy"
    AmazonRoute53RecoveryClusterFullAccess = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryClusterFullAccess"
    AmazonSageMakerCoreServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonSageMakerCoreServiceRolePolicy"
    AmazonCloudWatchRUMReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonCloudWatchRUMReadOnlyAccess"
    AWSThinkboxDeadlineSpotEventPluginAdminPolicy = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineSpotEventPluginAdminPolicy"
    AmazonLookoutMetricsReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonLookoutMetricsReadOnlyAccess"
    AWSDataExchangeFullAccess = "arn:aws:iam::aws:policy/AWSDataExchangeFullAccess"
    AWSDataExchangeProviderFullAccess = "arn:aws:iam::aws:policy/AWSDataExchangeProviderFullAccess"
    AWSBugBustFullAccess = "arn:aws:iam::aws:policy/AWSBugBustFullAccess"
    AWSServiceRolePolicyForBackupReports = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRolePolicyForBackupReports"
    CloudWatchApplicationInsightsFullAccess = "arn:aws:iam::aws:policy/CloudWatchApplicationInsightsFullAccess"
    AWSControlTowerServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSControlTowerServiceRolePolicy"
    AmazonSageMakerNotebooksServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonSageMakerNotebooksServiceRolePolicy"
    AmazonRoute53ResolverFullAccess = "arn:aws:iam::aws:policy/AmazonRoute53ResolverFullAccess"
    AWSSystemsManagerChangeManagementServicePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSSystemsManagerChangeManagementServicePolicy"
    AWSServiceCatalogAppRegistryFullAccess = "arn:aws:iam::aws:policy/AWSServiceCatalogAppRegistryFullAccess"
    LakeFormationDataAccessServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/LakeFormationDataAccessServiceRolePolicy"
    AWSMediaTailorServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSMediaTailorServiceRolePolicy"
    AmazonChimeServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeServiceRolePolicy"
    AmazonSageMakerAdmin_ServiceCatalogProductsServiceRolePolicy = "arn:aws:iam::aws:policy/AmazonSageMakerAdmin-ServiceCatalogProductsServiceRolePolicy"
    AmazonMSKConnectReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonMSKConnectReadOnlyAccess"
    AWSTrustedAdvisorReportingServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSTrustedAdvisorReportingServiceRolePolicy"
    AWSOpsWorksRegisterCLI_EC2 = "arn:aws:iam::aws:policy/AWSOpsWorksRegisterCLI_EC2"
    AWSWAFConsoleReadOnlyAccess = "arn:aws:iam::aws:policy/AWSWAFConsoleReadOnlyAccess"
    AWSSavingsPlansFullAccess = "arn:aws:iam::aws:policy/AWSSavingsPlansFullAccess"
    AWSServiceRoleForImageBuilder = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForImageBuilder"
    AWSElasticDisasterRecoveryRecoveryInstancePolicy = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryRecoveryInstancePolicy"
    AmazonOpenSearchServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonOpenSearchServiceRolePolicy"
    AmazonBraketServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonBraketServiceRolePolicy"
    AmazonCodeGuruProfilerAgentAccess = "arn:aws:iam::aws:policy/AmazonCodeGuruProfilerAgentAccess"
    AmazonLookoutVisionConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonLookoutVisionConsoleFullAccess"
    AWSAccountManagementFullAccess = "arn:aws:iam::aws:policy/AWSAccountManagementFullAccess"
    AmazonCodeGuruReviewerServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonCodeGuruReviewerServiceRolePolicy"
    ServerMigration_ServiceRole = "arn:aws:iam::aws:policy/service-role/ServerMigration_ServiceRole"
    AWSAppMeshPreviewEnvoyAccess = "arn:aws:iam::aws:policy/AWSAppMeshPreviewEnvoyAccess"
    AWSOutpostsServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSOutpostsServiceRolePolicy"
    AmazonEC2RoleforAWSCodeDeployLimited = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforAWSCodeDeployLimited"
    AWSElementalMediaTailorFullAccess = "arn:aws:iam::aws:policy/AWSElementalMediaTailorFullAccess"
    AWSMigrationHubStrategyConsoleFullAccess = "arn:aws:iam::aws:policy/AWSMigrationHubStrategyConsoleFullAccess"
    AWSIotRoboRunnerReadOnly = "arn:aws:iam::aws:policy/AWSIotRoboRunnerReadOnly"
    ECRReplicationServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ECRReplicationServiceRolePolicy"
    MigrationHubServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/MigrationHubServiceRolePolicy"
    AWSServiceRoleForMonitronPolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForMonitronPolicy"
    AWSPanoramaSageMakerRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSPanoramaSageMakerRolePolicy"
    AWSPanoramaApplianceServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AWSPanoramaApplianceServiceRolePolicy"
    AWSIoTWirelessGatewayCertManager = "arn:aws:iam::aws:policy/AWSIoTWirelessGatewayCertManager"
    AWSDirectConnectServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSDirectConnectServiceRolePolicy"
    AWSApplicationMigrationEC2Access = "arn:aws:iam::aws:policy/AWSApplicationMigrationEC2Access"
    AmazonCloudWatchEvidentlyFullAccess = "arn:aws:iam::aws:policy/AmazonCloudWatchEvidentlyFullAccess"
    AWSImageBuilderReadOnlyAccess = "arn:aws:iam::aws:policy/AWSImageBuilderReadOnlyAccess"
    AWSGrafanaConsoleReadOnlyAccess = "arn:aws:iam::aws:policy/AWSGrafanaConsoleReadOnlyAccess"
    AWSMarketplaceMeteringRegisterUsage = "arn:aws:iam::aws:policy/AWSMarketplaceMeteringRegisterUsage"
    AmazonManagedBlockchainReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonManagedBlockchainReadOnlyAccess"
    AmazonLookoutVisionReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonLookoutVisionReadOnlyAccess"
    AmazonRekognitionCustomLabelsFullAccess = "arn:aws:iam::aws:policy/AmazonRekognitionCustomLabelsFullAccess"
    AmazonHealthLakeFullAccess = "arn:aws:iam::aws:policy/AmazonHealthLakeFullAccess"
    AWSBackupServiceLinkedRolePolicyForBackup = "arn:aws:iam::aws:policy/aws-service-role/AWSBackupServiceLinkedRolePolicyForBackup"
    AmazonManagedBlockchainConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonManagedBlockchainConsoleFullAccess"
    AWSApplicationMigrationConversionServerPolicy = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationConversionServerPolicy"
    AWSSavingsPlansReadOnlyAccess = "arn:aws:iam::aws:policy/AWSSavingsPlansReadOnlyAccess"
    AWSMigrationHubRefactorSpacesFullAccess = "arn:aws:iam::aws:policy/AWSMigrationHubRefactorSpacesFullAccess"
    AmazonHoneycodeWorkbookFullAccess = "arn:aws:iam::aws:policy/AmazonHoneycodeWorkbookFullAccess"
    AWSIoTDeviceTesterForGreengrassFullAccess = "arn:aws:iam::aws:policy/AWSIoTDeviceTesterForGreengrassFullAccess"
    AWSElasticBeanstalkRoleECS = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleECS"
    AmazonWorkMailMessageFlowFullAccess = "arn:aws:iam::aws:policy/AmazonWorkMailMessageFlowFullAccess"
    AWSServiceRoleForSMS = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForSMS"
    AWSThinkboxDeadlineResourceTrackerAccessPolicy = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineResourceTrackerAccessPolicy"
    CloudWatch_CrossAccountAccess = "arn:aws:iam::aws:policy/aws-service-role/CloudWatch-CrossAccountAccess"
    AWSLakeFormationDataAdmin = "arn:aws:iam::aws:policy/AWSLakeFormationDataAdmin"
    AWSElasticBeanstalkRoleCore = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleCore"
    AWSLambda_FullAccess = "arn:aws:iam::aws:policy/AWSLambda_FullAccess"
    AmazonEMRContainersServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonEMRContainersServiceRolePolicy"
    AWSKeyManagementServiceMultiRegionKeysServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AWSKeyManagementServiceMultiRegionKeysServiceRolePolicy"
    AWSDenyAll = "arn:aws:iam::aws:policy/AWSDenyAll"
    AWSIQFullAccess = "arn:aws:iam::aws:policy/AWSIQFullAccess"
    AmazonElasticContainerRegistryPublicPowerUser = "arn:aws:iam::aws:policy/AmazonElasticContainerRegistryPublicPowerUser"
    AmazonPrometheusConsoleFullAccess = "arn:aws:iam::aws:policy/AmazonPrometheusConsoleFullAccess"
    AWSElasticBeanstalkRoleSNS = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleSNS"
    EC2FastLaunchServiceRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/EC2FastLaunchServiceRolePolicy"
    AmazonEKSVPCResourceController = "arn:aws:iam::aws:policy/AmazonEKSVPCResourceController"
    EC2InstanceConnect = "arn:aws:iam::aws:policy/EC2InstanceConnect"
    AWSCompromisedKeyQuarantineV2 = "arn:aws:iam::aws:policy/AWSCompromisedKeyQuarantineV2"
    AmazonS3ObjectLambdaExecutionRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonS3ObjectLambdaExecutionRolePolicy"
    ClientVPNServiceConnectionsRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/ClientVPNServiceConnectionsRolePolicy"
    AmazonAppFlowFullAccess = "arn:aws:iam::aws:policy/AmazonAppFlowFullAccess"
    AWSElasticDisasterRecoveryReplicationServerPolicy = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryReplicationServerPolicy"
    Ec2ImageBuilderCrossAccountDistributionAccess = "arn:aws:iam::aws:policy/Ec2ImageBuilderCrossAccountDistributionAccess"
    AWSThinkboxAWSPortalWorkerPolicy = "arn:aws:iam::aws:policy/AWSThinkboxAWSPortalWorkerPolicy"
    AmazonS3OutpostsReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonS3OutpostsReadOnlyAccess"
    AWSCompromisedKeyQuarantine = "arn:aws:iam::aws:policy/AWSCompromisedKeyQuarantine"
    AWSAppMeshEnvoyAccess = "arn:aws:iam::aws:policy/AWSAppMeshEnvoyAccess"
    AmazonSageMakerServiceCatalogProductsApiGatewayServiceRolePolicy = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsApiGatewayServiceRolePolicy"
    AWSAppRunnerReadOnlyAccess = "arn:aws:iam::aws:policy/AWSAppRunnerReadOnlyAccess"
    AmazonRoute53RecoveryClusterReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryClusterReadOnlyAccess"
    AmazonKendraReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonKendraReadOnlyAccess"
    AmazonPrometheusFullAccess = "arn:aws:iam::aws:policy/AmazonPrometheusFullAccess"
    AWS_ConfigRole = "arn:aws:iam::aws:policy/service-role/AWS_ConfigRole"
    AmazonOpenSearchServiceReadOnlyAccess = "arn:aws:iam::aws:policy/AmazonOpenSearchServiceReadOnlyAccess"
    AmazonConnectCampaignsServiceLinkedRolePolicy = "arn:aws:iam::aws:policy/aws-service-role/AmazonConnectCampaignsServiceLinkedRolePolicy"
    AmazonNimbleStudio_StudioAdmin = "arn:aws:iam::aws:policy/AmazonNimbleStudio-StudioAdmin"
    AWSCodeArtifactReadOnlyAccess = "arn:aws:iam::aws:policy/AWSCodeArtifactReadOnlyAccess"
    AmazonRedshiftDataFullAccess = "arn:aws:iam::aws:policy/AmazonRedshiftDataFullAccess"
    AWSApplicationMigrationReplicationServerPolicy = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationReplicationServerPolicy"